Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Association
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Association
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb
Overview
Association Model.
Instance Attribute Summary collapse
-
#ship_node ⇒ String
TODO: Write general description for this method.
-
#ship_node_name ⇒ String
TODO: Write general description for this method.
-
#shipping_template ⇒ ShippingTemplate
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(shipping_template = nil, ship_node_name = nil, ship_node = nil) ⇒ Association
constructor
A new instance of Association.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(shipping_template = nil, ship_node_name = nil, ship_node = nil) ⇒ Association
Returns a new instance of Association.
44 45 46 47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 44 def initialize(shipping_template = nil, ship_node_name = nil, ship_node = nil) @shipping_template = shipping_template @ship_node_name = ship_node_name @ship_node = ship_node end |
Instance Attribute Details
#ship_node ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 23 def ship_node @ship_node end |
#ship_node_name ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 19 def ship_node_name @ship_node_name end |
#shipping_template ⇒ ShippingTemplate
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 15 def shipping_template @shipping_template end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. shipping_template = ShippingTemplate.from_hash(hash['shippingTemplate']) if hash['shippingTemplate'] ship_node_name = hash.key?('shipNodeName') ? hash['shipNodeName'] : nil ship_node = hash.key?('shipNode') ? hash['shipNode'] : nil # Create object from extracted values. Association.new(shipping_template, ship_node_name, ship_node) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['shipping_template'] = 'shippingTemplate' @_hash['ship_node_name'] = 'shipNodeName' @_hash['ship_node'] = 'shipNode' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} shipping_template: #{@shipping_template.inspect}, ship_node_name:"\ " #{@ship_node_name.inspect}, ship_node: #{@ship_node.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
68 69 70 71 72 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/association.rb', line 68 def to_s class_name = self.class.name.split('::').last "<#{class_name} shipping_template: #{@shipping_template}, ship_node_name:"\ " #{@ship_node_name}, ship_node: #{@ship_node}>" end |