Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::AssociationsController

Inherits:
BaseController
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/controllers/associations_controller.rb

Overview

AssociationsController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::BaseController

Instance Method Details

#get_item_associations(wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept, body) ⇒ SuccessfulOperation21

Get Item Associations API allows you to retrieve the Shipping Templates and Fulfillment Centers associated with your item SKUs. By submitting a list of SKUs, you can obtain details such as the Shipping Template name, type, ID, and the associated Fulfillment Center (Ship Node) for each item. access token retrieved in the Token API call to track the consumer request by channel. Use the Consumer Channel Type received during onboarding unique ID which identifies each API call and used to track and debug issues; use a random generated GUID for this ID Name description here

Parameters:

  • wm_sec_access_token (String)

    Required parameter: (Required) The

  • wm_consumer_channel_type (String)

    Required parameter: A unique ID

  • wm_qos_correlation_id (String)

    Required parameter: (Required) A

  • wm_svc_name (String)

    Required parameter: (Required) Walmart Service

  • accept (String)

    Required parameter: TODO: type description here

  • body (GetItemAssociationsRequest)

    Required parameter: TODO: type

Returns:



29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/controllers/associations_controller.rb', line 29

def get_item_associations(wm_sec_access_token,
                          wm_consumer_channel_type,
                          wm_qos_correlation_id,
                          wm_svc_name,
                          accept,
                          body)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/items/associations',
                                 Server::DEFAULT)
               .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN'))
               .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE'))
               .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID'))
               .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME'))
               .header_param(new_parameter(accept, key: 'Accept'))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .body_serializer(proc do |param| param.to_json unless param.nil? end))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SuccessfulOperation21.method(:from_hash))
                .local_error('400',
                             'Bad Request',
                             ItemsAssociations400ErrorException)
                .local_error('500',
                             'Internal Server Error',
                             ItemsAssociations500ErrorException))
    .execute
end