Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::CatalogSearchRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::CatalogSearchRequest
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb
Overview
CatalogSearchRequest Model.
Instance Attribute Summary collapse
-
#filters ⇒ Array[Filter]
TODO: Write general description for this method.
-
#query ⇒ Query
TODO: Write general description for this method.
-
#sort ⇒ Sort
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(query = nil, filters = nil, sort = nil) ⇒ CatalogSearchRequest
constructor
A new instance of CatalogSearchRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(query = nil, filters = nil, sort = nil) ⇒ CatalogSearchRequest
Returns a new instance of CatalogSearchRequest.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 44 def initialize(query = nil, filters = nil, sort = nil) @query = query @filters = filters @sort = sort end |
Instance Attribute Details
#filters ⇒ Array[Filter]
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 19 def filters @filters end |
#query ⇒ Query
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 15 def query @query end |
#sort ⇒ Sort
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 23 def sort @sort end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. query = Query.from_hash(hash['query']) if hash['query'] # Parameter is an array, so we need to iterate through it filters = nil unless hash['filters'].nil? filters = [] hash['filters'].each do |structure| filters << (Filter.from_hash(structure) if structure) end end filters = nil unless hash.key?('filters') sort = Sort.from_hash(hash['sort']) if hash['sort'] # Create object from extracted values. CatalogSearchRequest.new(query, filters, sort) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['query'] = 'query' @_hash['filters'] = 'filters' @_hash['sort'] = 'sort' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} query: #{@query.inspect}, filters: #{@filters.inspect}, sort:"\ " #{@sort.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/catalog_search_request.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} query: #{@query}, filters: #{@filters}, sort: #{@sort}>" end |