Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ErrorIdentifiers
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ErrorIdentifiers
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb
Overview
ErrorIdentifiers Model.
Instance Attribute Summary collapse
-
#cillumfa ⇒ Object
TODO: Write general description for this method.
-
#enim_c43 ⇒ Object
TODO: Write general description for this method.
-
#nisi_c3 ⇒ Object
TODO: Write general description for this method.
-
#pariatur_5a ⇒ Object
TODO: Write general description for this method.
-
#qui3a ⇒ Object
TODO: Write general description for this method.
-
#quis_5 ⇒ Object
TODO: Write general description for this method.
-
#ut3 ⇒ Object
TODO: Write general description for this method.
-
#utb90 ⇒ Object
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(nisi_c3 = SKIP, quis_5 = SKIP, qui3a = SKIP, pariatur_5a = SKIP, utb90 = SKIP, cillumfa = SKIP, enim_c43 = SKIP, ut3 = SKIP) ⇒ ErrorIdentifiers
constructor
A new instance of ErrorIdentifiers.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(nisi_c3 = SKIP, quis_5 = SKIP, qui3a = SKIP, pariatur_5a = SKIP, utb90 = SKIP, cillumfa = SKIP, enim_c43 = SKIP, ut3 = SKIP) ⇒ ErrorIdentifiers
Returns a new instance of ErrorIdentifiers.
78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 78 def initialize(nisi_c3 = SKIP, quis_5 = SKIP, qui3a = SKIP, pariatur_5a = SKIP, utb90 = SKIP, cillumfa = SKIP, enim_c43 = SKIP, ut3 = SKIP) @nisi_c3 = nisi_c3 unless nisi_c3 == SKIP @quis_5 = quis_5 unless quis_5 == SKIP @qui3a = qui3a unless qui3a == SKIP @pariatur_5a = pariatur_5a unless pariatur_5a == SKIP @utb90 = utb90 unless utb90 == SKIP @cillumfa = cillumfa unless cillumfa == SKIP @enim_c43 = enim_c43 unless enim_c43 == SKIP @ut3 = ut3 unless ut3 == SKIP end |
Instance Attribute Details
#cillumfa ⇒ Object
TODO: Write general description for this method
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 35 def cillumfa @cillumfa end |
#enim_c43 ⇒ Object
TODO: Write general description for this method
39 40 41 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 39 def enim_c43 @enim_c43 end |
#nisi_c3 ⇒ Object
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 15 def nisi_c3 @nisi_c3 end |
#pariatur_5a ⇒ Object
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 27 def pariatur_5a @pariatur_5a end |
#qui3a ⇒ Object
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 23 def qui3a @qui3a end |
#quis_5 ⇒ Object
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 19 def quis_5 @quis_5 end |
#ut3 ⇒ Object
TODO: Write general description for this method
43 44 45 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 43 def ut3 @ut3 end |
#utb90 ⇒ Object
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 31 def utb90 @utb90 end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 92 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. nisi_c3 = hash.key?('nisi_c3') ? hash['nisi_c3'] : SKIP quis_5 = hash.key?('quis_5') ? hash['quis_5'] : SKIP qui3a = hash.key?('qui3a') ? hash['qui3a'] : SKIP pariatur_5a = hash.key?('pariatur_5a') ? hash['pariatur_5a'] : SKIP utb90 = hash.key?('Utb90') ? hash['Utb90'] : SKIP cillumfa = hash.key?('cillumfa') ? hash['cillumfa'] : SKIP enim_c43 = hash.key?('enim_c43') ? hash['enim_c43'] : SKIP ut3 = hash.key?('ut3') ? hash['ut3'] : SKIP # Create object from extracted values. ErrorIdentifiers.new(nisi_c3, quis_5, qui3a, pariatur_5a, utb90, cillumfa, enim_c43, ut3) end |
.names ⇒ Object
A mapping from model property names to API property names.
46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 46 def self.names @_hash = {} if @_hash.nil? @_hash['nisi_c3'] = 'nisi_c3' @_hash['quis_5'] = 'quis_5' @_hash['qui3a'] = 'qui3a' @_hash['pariatur_5a'] = 'pariatur_5a' @_hash['utb90'] = 'Utb90' @_hash['cillumfa'] = 'cillumfa' @_hash['enim_c43'] = 'enim_c43' @_hash['ut3'] = 'ut3' @_hash end |
.nullables ⇒ Object
An array for nullable fields
74 75 76 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 74 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 60 def self.optionals %w[ nisi_c3 quis_5 qui3a pariatur_5a utb90 cillumfa enim_c43 ut3 ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
125 126 127 128 129 130 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 125 def inspect class_name = self.class.name.split('::').last "<#{class_name} nisi_c3: #{@nisi_c3.inspect}, quis_5: #{@quis_5.inspect}, qui3a:"\ " #{@qui3a.inspect}, pariatur_5a: #{@pariatur_5a.inspect}, utb90: #{@utb90.inspect},"\ " cillumfa: #{@cillumfa.inspect}, enim_c43: #{@enim_c43.inspect}, ut3: #{@ut3.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
117 118 119 120 121 122 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers.rb', line 117 def to_s class_name = self.class.name.split('::').last "<#{class_name} nisi_c3: #{@nisi_c3}, quis_5: #{@quis_5}, qui3a: #{@qui3a}, pariatur_5a:"\ " #{@pariatur_5a}, utb90: #{@utb90}, cillumfa: #{@cillumfa}, enim_c43: #{@enim_c43}, ut3:"\ " #{@ut3}>" end |