Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ErrorIdentifiers1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ErrorIdentifiers1
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb
Overview
ErrorIdentifiers1 Model.
Instance Attribute Summary collapse
-
#aliquip_9ad ⇒ Object
TODO: Write general description for this method.
-
#aute7 ⇒ Object
TODO: Write general description for this method.
-
#doc ⇒ Object
TODO: Write general description for this method.
-
#dolor_2ca ⇒ Object
TODO: Write general description for this method.
-
#est_d05 ⇒ Object
TODO: Write general description for this method.
-
#in369 ⇒ Object
TODO: Write general description for this method.
-
#minim04 ⇒ Object
TODO: Write general description for this method.
-
#occaecatab ⇒ Object
TODO: Write general description for this method.
-
#quic ⇒ Object
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(dolor_2ca = SKIP, occaecatab = SKIP, aliquip_9ad = SKIP, doc = SKIP, quic = SKIP, minim04 = SKIP, aute7 = SKIP, est_d05 = SKIP, in369 = SKIP) ⇒ ErrorIdentifiers1
constructor
A new instance of ErrorIdentifiers1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(dolor_2ca = SKIP, occaecatab = SKIP, aliquip_9ad = SKIP, doc = SKIP, quic = SKIP, minim04 = SKIP, aute7 = SKIP, est_d05 = SKIP, in369 = SKIP) ⇒ ErrorIdentifiers1
Returns a new instance of ErrorIdentifiers1.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 84 def initialize(dolor_2ca = SKIP, occaecatab = SKIP, aliquip_9ad = SKIP, doc = SKIP, quic = SKIP, minim04 = SKIP, aute7 = SKIP, est_d05 = SKIP, in369 = SKIP) @dolor_2ca = dolor_2ca unless dolor_2ca == SKIP @occaecatab = occaecatab unless occaecatab == SKIP @aliquip_9ad = aliquip_9ad unless aliquip_9ad == SKIP @doc = doc unless doc == SKIP @quic = quic unless quic == SKIP @minim04 = minim04 unless minim04 == SKIP @aute7 = aute7 unless aute7 == SKIP @est_d05 = est_d05 unless est_d05 == SKIP @in369 = in369 unless in369 == SKIP end |
Instance Attribute Details
#aliquip_9ad ⇒ Object
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 23 def aliquip_9ad @aliquip_9ad end |
#aute7 ⇒ Object
TODO: Write general description for this method
39 40 41 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 39 def aute7 @aute7 end |
#doc ⇒ Object
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 27 def doc @doc end |
#dolor_2ca ⇒ Object
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 15 def dolor_2ca @dolor_2ca end |
#est_d05 ⇒ Object
TODO: Write general description for this method
43 44 45 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 43 def est_d05 @est_d05 end |
#in369 ⇒ Object
TODO: Write general description for this method
47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 47 def in369 @in369 end |
#minim04 ⇒ Object
TODO: Write general description for this method
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 35 def minim04 @minim04 end |
#occaecatab ⇒ Object
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 19 def occaecatab @occaecatab end |
#quic ⇒ Object
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 31 def quic @quic end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 99 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. dolor_2ca = hash.key?('dolor_2ca') ? hash['dolor_2ca'] : SKIP occaecatab = hash.key?('occaecatab') ? hash['occaecatab'] : SKIP aliquip_9ad = hash.key?('aliquip_9ad') ? hash['aliquip_9ad'] : SKIP doc = hash.key?('doc') ? hash['doc'] : SKIP quic = hash.key?('quic') ? hash['quic'] : SKIP minim04 = hash.key?('minim04_') ? hash['minim04_'] : SKIP aute7 = hash.key?('aute7') ? hash['aute7'] : SKIP est_d05 = hash.key?('est_d05') ? hash['est_d05'] : SKIP in369 = hash.key?('in369') ? hash['in369'] : SKIP # Create object from extracted values. ErrorIdentifiers1.new(dolor_2ca, occaecatab, aliquip_9ad, doc, quic, minim04, aute7, est_d05, in369) end |
.names ⇒ Object
A mapping from model property names to API property names.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 50 def self.names @_hash = {} if @_hash.nil? @_hash['dolor_2ca'] = 'dolor_2ca' @_hash['occaecatab'] = 'occaecatab' @_hash['aliquip_9ad'] = 'aliquip_9ad' @_hash['doc'] = 'doc' @_hash['quic'] = 'quic' @_hash['minim04'] = 'minim04_' @_hash['aute7'] = 'aute7' @_hash['est_d05'] = 'est_d05' @_hash['in369'] = 'in369' @_hash end |
.nullables ⇒ Object
An array for nullable fields
80 81 82 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 80 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 65 def self.optionals %w[ dolor_2ca occaecatab aliquip_9ad doc quic minim04 aute7 est_d05 in369 ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
134 135 136 137 138 139 140 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 134 def inspect class_name = self.class.name.split('::').last "<#{class_name} dolor_2ca: #{@dolor_2ca.inspect}, occaecatab: #{@occaecatab.inspect},"\ " aliquip_9ad: #{@aliquip_9ad.inspect}, doc: #{@doc.inspect}, quic: #{@quic.inspect},"\ " minim04: #{@minim04.inspect}, aute7: #{@aute7.inspect}, est_d05: #{@est_d05.inspect},"\ " in369: #{@in369.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
126 127 128 129 130 131 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers1.rb', line 126 def to_s class_name = self.class.name.split('::').last "<#{class_name} dolor_2ca: #{@dolor_2ca}, occaecatab: #{@occaecatab}, aliquip_9ad:"\ " #{@aliquip_9ad}, doc: #{@doc}, quic: #{@quic}, minim04: #{@minim04}, aute7: #{@aute7},"\ " est_d05: #{@est_d05}, in369: #{@in369}>" end |