Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ErrorIdentifiers2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ErrorIdentifiers2
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb
Overview
ErrorIdentifiers2 Model.
Instance Attribute Summary collapse
-
#anim_ebc ⇒ Object
TODO: Write general description for this method.
-
#consectetur9 ⇒ Object
TODO: Write general description for this method.
-
#eiusmod_a ⇒ Object
TODO: Write general description for this method.
-
#euf3 ⇒ Object
TODO: Write general description for this method.
-
#fugiat_ca ⇒ Object
TODO: Write general description for this method.
-
#ipsum_3 ⇒ Object
TODO: Write general description for this method.
-
#sintb0b ⇒ Object
TODO: Write general description for this method.
-
#sit_6 ⇒ Object
TODO: Write general description for this method.
-
#ullamco409 ⇒ Object
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(sit_6 = SKIP, ullamco409 = SKIP, sintb0b = SKIP, eiusmod_a = SKIP, euf3 = SKIP, ipsum_3 = SKIP, anim_ebc = SKIP, consectetur9 = SKIP, fugiat_ca = SKIP) ⇒ ErrorIdentifiers2
constructor
A new instance of ErrorIdentifiers2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(sit_6 = SKIP, ullamco409 = SKIP, sintb0b = SKIP, eiusmod_a = SKIP, euf3 = SKIP, ipsum_3 = SKIP, anim_ebc = SKIP, consectetur9 = SKIP, fugiat_ca = SKIP) ⇒ ErrorIdentifiers2
Returns a new instance of ErrorIdentifiers2.
84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 84 def initialize(sit_6 = SKIP, ullamco409 = SKIP, sintb0b = SKIP, eiusmod_a = SKIP, euf3 = SKIP, ipsum_3 = SKIP, anim_ebc = SKIP, consectetur9 = SKIP, fugiat_ca = SKIP) @sit_6 = sit_6 unless sit_6 == SKIP @ullamco409 = ullamco409 unless ullamco409 == SKIP @sintb0b = sintb0b unless sintb0b == SKIP @eiusmod_a = eiusmod_a unless eiusmod_a == SKIP @euf3 = euf3 unless euf3 == SKIP @ipsum_3 = ipsum_3 unless ipsum_3 == SKIP @anim_ebc = anim_ebc unless anim_ebc == SKIP @consectetur9 = consectetur9 unless consectetur9 == SKIP @fugiat_ca = fugiat_ca unless fugiat_ca == SKIP end |
Instance Attribute Details
#anim_ebc ⇒ Object
TODO: Write general description for this method
39 40 41 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 39 def anim_ebc @anim_ebc end |
#consectetur9 ⇒ Object
TODO: Write general description for this method
43 44 45 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 43 def consectetur9 @consectetur9 end |
#eiusmod_a ⇒ Object
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 27 def eiusmod_a @eiusmod_a end |
#euf3 ⇒ Object
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 31 def euf3 @euf3 end |
#fugiat_ca ⇒ Object
TODO: Write general description for this method
47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 47 def fugiat_ca @fugiat_ca end |
#ipsum_3 ⇒ Object
TODO: Write general description for this method
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 35 def ipsum_3 @ipsum_3 end |
#sintb0b ⇒ Object
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 23 def sintb0b @sintb0b end |
#sit_6 ⇒ Object
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 15 def sit_6 @sit_6 end |
#ullamco409 ⇒ Object
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 19 def ullamco409 @ullamco409 end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 99 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. sit_6 = hash.key?('sit_6') ? hash['sit_6'] : SKIP ullamco409 = hash.key?('ullamco409') ? hash['ullamco409'] : SKIP sintb0b = hash.key?('sintb0b') ? hash['sintb0b'] : SKIP eiusmod_a = hash.key?('eiusmod_a') ? hash['eiusmod_a'] : SKIP euf3 = hash.key?('euf3') ? hash['euf3'] : SKIP ipsum_3 = hash.key?('ipsum_3') ? hash['ipsum_3'] : SKIP anim_ebc = hash.key?('anim_ebc') ? hash['anim_ebc'] : SKIP consectetur9 = hash.key?('consectetur9') ? hash['consectetur9'] : SKIP fugiat_ca = hash.key?('fugiat_ca_') ? hash['fugiat_ca_'] : SKIP # Create object from extracted values. ErrorIdentifiers2.new(sit_6, ullamco409, sintb0b, eiusmod_a, euf3, ipsum_3, anim_ebc, consectetur9, fugiat_ca) end |
.names ⇒ Object
A mapping from model property names to API property names.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 50 def self.names @_hash = {} if @_hash.nil? @_hash['sit_6'] = 'sit_6' @_hash['ullamco409'] = 'ullamco409' @_hash['sintb0b'] = 'sintb0b' @_hash['eiusmod_a'] = 'eiusmod_a' @_hash['euf3'] = 'euf3' @_hash['ipsum_3'] = 'ipsum_3' @_hash['anim_ebc'] = 'anim_ebc' @_hash['consectetur9'] = 'consectetur9' @_hash['fugiat_ca'] = 'fugiat_ca_' @_hash end |
.nullables ⇒ Object
An array for nullable fields
80 81 82 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 80 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 65 def self.optionals %w[ sit_6 ullamco409 sintb0b eiusmod_a euf3 ipsum_3 anim_ebc consectetur9 fugiat_ca ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
134 135 136 137 138 139 140 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 134 def inspect class_name = self.class.name.split('::').last "<#{class_name} sit_6: #{@sit_6.inspect}, ullamco409: #{@ullamco409.inspect}, sintb0b:"\ " #{@sintb0b.inspect}, eiusmod_a: #{@eiusmod_a.inspect}, euf3: #{@euf3.inspect}, ipsum_3:"\ " #{@ipsum_3.inspect}, anim_ebc: #{@anim_ebc.inspect}, consectetur9:"\ " #{@consectetur9.inspect}, fugiat_ca: #{@fugiat_ca.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
126 127 128 129 130 131 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers2.rb', line 126 def to_s class_name = self.class.name.split('::').last "<#{class_name} sit_6: #{@sit_6}, ullamco409: #{@ullamco409}, sintb0b: #{@sintb0b},"\ " eiusmod_a: #{@eiusmod_a}, euf3: #{@euf3}, ipsum_3: #{@ipsum_3}, anim_ebc: #{@anim_ebc},"\ " consectetur9: #{@consectetur9}, fugiat_ca: #{@fugiat_ca}>" end |