Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ErrorIdentifiers3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ErrorIdentifiers3
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb
Overview
ErrorIdentifiers3 Model.
Instance Attribute Summary collapse
-
#amet_8c6 ⇒ Object
TODO: Write general description for this method.
-
#anim_6e8 ⇒ Object
TODO: Write general description for this method.
-
#cillum7e ⇒ Object
TODO: Write general description for this method.
-
#id623 ⇒ Object
TODO: Write general description for this method.
-
#magna_76c ⇒ Object
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amet_8c6 = SKIP, cillum7e = SKIP, magna_76c = SKIP, anim_6e8 = SKIP, id623 = SKIP) ⇒ ErrorIdentifiers3
constructor
A new instance of ErrorIdentifiers3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amet_8c6 = SKIP, cillum7e = SKIP, magna_76c = SKIP, anim_6e8 = SKIP, id623 = SKIP) ⇒ ErrorIdentifiers3
Returns a new instance of ErrorIdentifiers3.
60 61 62 63 64 65 66 67 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 60 def initialize(amet_8c6 = SKIP, cillum7e = SKIP, magna_76c = SKIP, anim_6e8 = SKIP, id623 = SKIP) @amet_8c6 = amet_8c6 unless amet_8c6 == SKIP @cillum7e = cillum7e unless cillum7e == SKIP @magna_76c = magna_76c unless magna_76c == SKIP @anim_6e8 = anim_6e8 unless anim_6e8 == SKIP @id623 = id623 unless id623 == SKIP end |
Instance Attribute Details
#amet_8c6 ⇒ Object
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 15 def amet_8c6 @amet_8c6 end |
#anim_6e8 ⇒ Object
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 27 def anim_6e8 @anim_6e8 end |
#cillum7e ⇒ Object
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 19 def cillum7e @cillum7e end |
#id623 ⇒ Object
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 31 def id623 @id623 end |
#magna_76c ⇒ Object
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 23 def magna_76c @magna_76c end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amet_8c6 = hash.key?('amet_8c6') ? hash['amet_8c6'] : SKIP cillum7e = hash.key?('cillum7e') ? hash['cillum7e'] : SKIP magna_76c = hash.key?('magna_76c') ? hash['magna_76c'] : SKIP anim_6e8 = hash.key?('anim_6e8') ? hash['anim_6e8'] : SKIP id623 = hash.key?('id623') ? hash['id623'] : SKIP # Create object from extracted values. ErrorIdentifiers3.new(amet_8c6, cillum7e, magna_76c, anim_6e8, id623) end |
.names ⇒ Object
A mapping from model property names to API property names.
34 35 36 37 38 39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 34 def self.names @_hash = {} if @_hash.nil? @_hash['amet_8c6'] = 'amet_8c6' @_hash['cillum7e'] = 'cillum7e' @_hash['magna_76c'] = 'magna_76c' @_hash['anim_6e8'] = 'anim_6e8' @_hash['id623'] = 'id623' @_hash end |
.nullables ⇒ Object
An array for nullable fields
56 57 58 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 56 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
45 46 47 48 49 50 51 52 53 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 45 def self.optionals %w[ amet_8c6 cillum7e magna_76c anim_6e8 id623 ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
96 97 98 99 100 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 96 def inspect class_name = self.class.name.split('::').last "<#{class_name} amet_8c6: #{@amet_8c6.inspect}, cillum7e: #{@cillum7e.inspect}, magna_76c:"\ " #{@magna_76c.inspect}, anim_6e8: #{@anim_6e8.inspect}, id623: #{@id623.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
89 90 91 92 93 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/error_identifiers3.rb', line 89 def to_s class_name = self.class.name.split('::').last "<#{class_name} amet_8c6: #{@amet_8c6}, cillum7e: #{@cillum7e}, magna_76c: #{@magna_76c},"\ " anim_6e8: #{@anim_6e8}, id623: #{@id623}>" end |