Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Filter1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Filter1
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb
Overview
Filter1 Model.
Instance Attribute Summary collapse
-
#name ⇒ String
TODO: Write general description for this method.
-
#operator ⇒ String
TODO: Write general description for this method.
-
#value ⇒ Array[Integer]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(name = nil, operator = nil, value = nil) ⇒ Filter1
constructor
A new instance of Filter1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(name = nil, operator = nil, value = nil) ⇒ Filter1
Returns a new instance of Filter1.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 44 def initialize(name = nil, operator = nil, value = nil) @name = name @operator = operator @value = value end |
Instance Attribute Details
#name ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 15 def name @name end |
#operator ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 19 def operator @operator end |
#value ⇒ Array[Integer]
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 23 def value @value end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. name = hash.key?('name') ? hash['name'] : nil operator = hash.key?('operator') ? hash['operator'] : nil value = hash.key?('value') ? hash['value'] : nil # Create object from extracted values. Filter1.new(name, operator, value) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['name'] = 'name' @_hash['operator'] = 'operator' @_hash['value'] = 'value' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} name: #{@name.inspect}, operator: #{@operator.inspect}, value:"\ " #{@value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/filter1.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} name: #{@name}, operator: #{@operator}, value: #{@value}>" end |