Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Fulfillment
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Fulfillment
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb
Overview
Fulfillment Model.
Instance Attribute Summary collapse
-
#fulfillment_option ⇒ String
TODO: Write general description for this method.
-
#pick_up_by ⇒ String
TODO: Write general description for this method.
-
#pick_up_date_time ⇒ String
TODO: Write general description for this method.
-
#ship_method ⇒ String
TODO: Write general description for this method.
-
#shipping_program_type ⇒ String
TODO: Write general description for this method.
-
#store_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(fulfillment_option = nil, ship_method = nil, store_id = nil, pick_up_date_time = nil, pick_up_by = nil, shipping_program_type = nil) ⇒ Fulfillment
constructor
A new instance of Fulfillment.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(fulfillment_option = nil, ship_method = nil, store_id = nil, pick_up_date_time = nil, pick_up_by = nil, shipping_program_type = nil) ⇒ Fulfillment
Returns a new instance of Fulfillment.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 59 def initialize(fulfillment_option = nil, ship_method = nil, store_id = nil, pick_up_date_time = nil, pick_up_by = nil, shipping_program_type = nil) @fulfillment_option = fulfillment_option @ship_method = ship_method @store_id = store_id @pick_up_date_time = pick_up_date_time @pick_up_by = pick_up_by @shipping_program_type = shipping_program_type end |
Instance Attribute Details
#fulfillment_option ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 15 def fulfillment_option @fulfillment_option end |
#pick_up_by ⇒ String
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 31 def pick_up_by @pick_up_by end |
#pick_up_date_time ⇒ String
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 27 def pick_up_date_time @pick_up_date_time end |
#ship_method ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 19 def ship_method @ship_method end |
#shipping_program_type ⇒ String
TODO: Write general description for this method
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 35 def shipping_program_type @shipping_program_type end |
#store_id ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 23 def store_id @store_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 71 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. fulfillment_option = hash.key?('fulfillmentOption') ? hash['fulfillmentOption'] : nil ship_method = hash.key?('shipMethod') ? hash['shipMethod'] : nil store_id = hash.key?('storeId') ? hash['storeId'] : nil pick_up_date_time = hash.key?('pickUpDateTime') ? hash['pickUpDateTime'] : nil pick_up_by = hash.key?('pickUpBy') ? hash['pickUpBy'] : nil shipping_program_type = hash.key?('shippingProgramType') ? hash['shippingProgramType'] : nil # Create object from extracted values. Fulfillment.new(fulfillment_option, ship_method, store_id, pick_up_date_time, pick_up_by, shipping_program_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['fulfillment_option'] = 'fulfillmentOption' @_hash['ship_method'] = 'shipMethod' @_hash['store_id'] = 'storeId' @_hash['pick_up_date_time'] = 'pickUpDateTime' @_hash['pick_up_by'] = 'pickUpBy' @_hash['shipping_program_type'] = 'shippingProgramType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 50 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
103 104 105 106 107 108 109 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 103 def inspect class_name = self.class.name.split('::').last "<#{class_name} fulfillment_option: #{@fulfillment_option.inspect}, ship_method:"\ " #{@ship_method.inspect}, store_id: #{@store_id.inspect}, pick_up_date_time:"\ " #{@pick_up_date_time.inspect}, pick_up_by: #{@pick_up_by.inspect}, shipping_program_type:"\ " #{@shipping_program_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
95 96 97 98 99 100 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/fulfillment.rb', line 95 def to_s class_name = self.class.name.split('::').last "<#{class_name} fulfillment_option: #{@fulfillment_option}, ship_method: #{@ship_method},"\ " store_id: #{@store_id}, pick_up_date_time: #{@pick_up_date_time}, pick_up_by:"\ " #{@pick_up_by}, shipping_program_type: #{@shipping_program_type}>" end |