Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::GetSpecRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::GetSpecRequest
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb
Overview
GetSpecRequest Model.
Instance Attribute Summary collapse
-
#feed_type ⇒ String
TODO: Write general description for this method.
-
#product_types ⇒ Array[String]
TODO: Write general description for this method.
-
#version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(feed_type = nil, version = nil, product_types = nil) ⇒ GetSpecRequest
constructor
A new instance of GetSpecRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(feed_type = nil, version = nil, product_types = nil) ⇒ GetSpecRequest
Returns a new instance of GetSpecRequest.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 44 def initialize(feed_type = nil, version = nil, product_types = nil) @feed_type = feed_type @version = version @product_types = product_types end |
Instance Attribute Details
#feed_type ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 15 def feed_type @feed_type end |
#product_types ⇒ Array[String]
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 23 def product_types @product_types end |
#version ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 19 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. feed_type = hash.key?('feedType') ? hash['feedType'] : nil version = hash.key?('version') ? hash['version'] : nil product_types = hash.key?('productTypes') ? hash['productTypes'] : nil # Create object from extracted values. GetSpecRequest.new(feed_type, version, product_types) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['feed_type'] = 'feedType' @_hash['version'] = 'version' @_hash['product_types'] = 'productTypes' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} feed_type: #{@feed_type.inspect}, version: #{@version.inspect},"\ " product_types: #{@product_types.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/get_spec_request.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} feed_type: #{@feed_type}, version: #{@version}, product_types:"\ " #{@product_types}>" end |