Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Headers
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Headers
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb
Overview
Headers Model.
Instance Attribute Summary collapse
-
#limit ⇒ String
TODO: Write general description for this method.
-
#offset ⇒ String
TODO: Write general description for this method.
-
#total_count ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(total_count = nil, limit = nil, offset = nil) ⇒ Headers
constructor
A new instance of Headers.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(total_count = nil, limit = nil, offset = nil) ⇒ Headers
Returns a new instance of Headers.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 44 def initialize(total_count = nil, limit = nil, offset = nil) @total_count = total_count @limit = limit @offset = offset end |
Instance Attribute Details
#limit ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 19 def limit @limit end |
#offset ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 23 def offset @offset end |
#total_count ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 15 def total_count @total_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. total_count = hash.key?('totalCount') ? hash['totalCount'] : nil limit = hash.key?('limit') ? hash['limit'] : nil offset = hash.key?('offset') ? hash['offset'] : nil # Create object from extracted values. Headers.new(total_count, limit, offset) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['total_count'] = 'totalCount' @_hash['limit'] = 'limit' @_hash['offset'] = 'offset' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} total_count: #{@total_count.inspect}, limit: #{@limit.inspect}, offset:"\ " #{@offset.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/headers.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} total_count: #{@total_count}, limit: #{@limit}, offset: #{@offset}>" end |