Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::IncentivesEnrollment
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::IncentivesEnrollment
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb
Overview
IncentivesEnrollment Model.
Instance Attribute Summary collapse
-
#incentive_id ⇒ String
TODO: Write general description for this method.
-
#incentive_type ⇒ String
TODO: Write general description for this method.
-
#referral_fee_incentive_enrollment ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(referral_fee_incentive_enrollment = nil, incentive_type = nil, incentive_id = nil) ⇒ IncentivesEnrollment
constructor
A new instance of IncentivesEnrollment.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(referral_fee_incentive_enrollment = nil, incentive_type = nil, incentive_id = nil) ⇒ IncentivesEnrollment
Returns a new instance of IncentivesEnrollment.
45 46 47 48 49 50 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 45 def initialize(referral_fee_incentive_enrollment = nil, incentive_type = nil, incentive_id = nil) @referral_fee_incentive_enrollment = referral_fee_incentive_enrollment @incentive_type = incentive_type @incentive_id = incentive_id end |
Instance Attribute Details
#incentive_id ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 23 def incentive_id @incentive_id end |
#incentive_type ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 19 def incentive_type @incentive_type end |
#referral_fee_incentive_enrollment ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 15 def referral_fee_incentive_enrollment @referral_fee_incentive_enrollment end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. referral_fee_incentive_enrollment = hash.key?('referralFeeIncentiveEnrollment') ? hash['referralFeeIncentiveEnrollment'] : nil incentive_type = hash.key?('incentiveType') ? hash['incentiveType'] : nil incentive_id = hash.key?('incentiveId') ? hash['incentiveId'] : nil # Create object from extracted values. IncentivesEnrollment.new(referral_fee_incentive_enrollment, incentive_type, incentive_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['referral_fee_incentive_enrollment'] = 'referralFeeIncentiveEnrollment' @_hash['incentive_type'] = 'incentiveType' @_hash['incentive_id'] = 'incentiveId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
36 37 38 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 36 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 81 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} referral_fee_incentive_enrollment:"\ " #{@referral_fee_incentive_enrollment.inspect}, incentive_type: #{@incentive_type.inspect},"\ " incentive_id: #{@incentive_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/incentives_enrollment.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} referral_fee_incentive_enrollment: #{@referral_fee_incentive_enrollment},"\ " incentive_type: #{@incentive_type}, incentive_id: #{@incentive_id}>" end |