Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ItemPriceResponse
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ItemPriceResponse
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb
Overview
ItemPriceResponse Model.
Instance Attribute Summary collapse
-
#mart ⇒ String
TODO: Write general description for this method.
-
#message ⇒ String
TODO: Write general description for this method.
-
#sku ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mart = nil, message = nil, sku = nil) ⇒ ItemPriceResponse
constructor
A new instance of ItemPriceResponse.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mart = nil, message = nil, sku = nil) ⇒ ItemPriceResponse
Returns a new instance of ItemPriceResponse.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 44 def initialize(mart = nil, = nil, sku = nil) @mart = mart @message = @sku = sku end |
Instance Attribute Details
#mart ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 15 def mart @mart end |
#message ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 19 def @message end |
#sku ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 23 def sku @sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mart = hash.key?('mart') ? hash['mart'] : nil = hash.key?('message') ? hash['message'] : nil sku = hash.key?('sku') ? hash['sku'] : nil # Create object from extracted values. ItemPriceResponse.new(mart, , sku) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['mart'] = 'mart' @_hash['message'] = 'message' @_hash['sku'] = 'sku' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
72 73 74 75 76 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 72 def inspect class_name = self.class.name.split('::').last "<#{class_name} mart: #{@mart.inspect}, message: #{@message.inspect}, sku:"\ " #{@sku.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_price_response.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} mart: #{@mart}, message: #{@message}, sku: #{@sku}>" end |