Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ItemTaxonomy

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb

Overview

ItemTaxonomy Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(category = nil, description = nil, product_type_group = nil) ⇒ ItemTaxonomy

Returns a new instance of ItemTaxonomy.



44
45
46
47
48
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 44

def initialize(category = nil, description = nil, product_type_group = nil)
  @category = category
  @description = description
  @product_type_group = product_type_group
end

Instance Attribute Details

#categoryString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 15

def category
  @category
end

#descriptionString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 19

def description
  @description
end

#product_type_groupArray[ProductTypeGroup]

TODO: Write general description for this method

Returns:



23
24
25
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 23

def product_type_group
  @product_type_group
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  category = hash.key?('category') ? hash['category'] : nil
  description = hash.key?('description') ? hash['description'] : nil
  # Parameter is an array, so we need to iterate through it
  product_type_group = nil
  unless hash['productTypeGroup'].nil?
    product_type_group = []
    hash['productTypeGroup'].each do |structure|
      product_type_group << (ProductTypeGroup.from_hash(structure) if structure)
    end
  end

  product_type_group = nil unless hash.key?('productTypeGroup')

  # Create object from extracted values.
  ItemTaxonomy.new(category,
                   description,
                   product_type_group)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['category'] = 'category'
  @_hash['description'] = 'description'
  @_hash['product_type_group'] = 'productTypeGroup'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} category: #{@category.inspect}, description: #{@description.inspect},"\
  " product_type_group: #{@product_type_group.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/item_taxonomy.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} category: #{@category}, description: #{@description}, product_type_group:"\
  " #{@product_type_group}>"
end