Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::MPItemFeedHeader
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::MPItemFeedHeader
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb
Overview
MPItemFeedHeader Model.
Instance Attribute Summary collapse
-
#business_unit ⇒ String
TODO: Write general description for this method.
-
#locale ⇒ String
TODO: Write general description for this method.
-
#version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(business_unit = nil, version = nil, locale = nil) ⇒ MPItemFeedHeader
constructor
A new instance of MPItemFeedHeader.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(business_unit = nil, version = nil, locale = nil) ⇒ MPItemFeedHeader
Returns a new instance of MPItemFeedHeader.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 44 def initialize(business_unit = nil, version = nil, locale = nil) @business_unit = business_unit @version = version @locale = locale end |
Instance Attribute Details
#business_unit ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 15 def business_unit @business_unit end |
#locale ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 23 def locale @locale end |
#version ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 19 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. business_unit = hash.key?('businessUnit') ? hash['businessUnit'] : nil version = hash.key?('version') ? hash['version'] : nil locale = hash.key?('locale') ? hash['locale'] : nil # Create object from extracted values. MPItemFeedHeader.new(business_unit, version, locale) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['business_unit'] = 'businessUnit' @_hash['version'] = 'version' @_hash['locale'] = 'locale' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} business_unit: #{@business_unit.inspect}, version: #{@version.inspect},"\ " locale: #{@locale.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/mp_item_feed_header.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} business_unit: #{@business_unit}, version: #{@version}, locale:"\ " #{@locale}>" end |