Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Meta
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Meta
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb
Overview
Meta Model.
Instance Attribute Summary collapse
-
#next_cursor ⇒ String
TODO: Write general description for this method.
-
#total_count ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(total_count = nil, next_cursor = nil) ⇒ Meta
constructor
A new instance of Meta.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(total_count = nil, next_cursor = nil) ⇒ Meta
Returns a new instance of Meta.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 39 def initialize(total_count = nil, next_cursor = nil) @total_count = total_count @next_cursor = next_cursor end |
Instance Attribute Details
#next_cursor ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 19 def next_cursor @next_cursor end |
#total_count ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 15 def total_count @total_count end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. total_count = hash.key?('totalCount') ? hash['totalCount'] : nil next_cursor = hash.key?('nextCursor') ? hash['nextCursor'] : nil # Create object from extracted values. Meta.new(total_count, next_cursor) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['total_count'] = 'totalCount' @_hash['next_cursor'] = 'nextCursor' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 68 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} total_count: #{@total_count.inspect}, next_cursor:"\ " #{@next_cursor.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/meta.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} total_count: #{@total_count}, next_cursor: #{@next_cursor}>" end |