Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Node1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Node1
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb
Overview
Node1 Model.
Instance Attribute Summary collapse
-
#input_qty ⇒ Quantity
TODO: Write general description for this method.
-
#inventory_available_date ⇒ String
TODO: Write general description for this method.
-
#ship_node ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(input_qty = nil, ship_node = nil, inventory_available_date = nil) ⇒ Node1
constructor
A new instance of Node1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(input_qty = nil, ship_node = nil, inventory_available_date = nil) ⇒ Node1
Returns a new instance of Node1.
44 45 46 47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 44 def initialize(input_qty = nil, ship_node = nil, inventory_available_date = nil) @input_qty = input_qty @ship_node = ship_node @inventory_available_date = inventory_available_date end |
Instance Attribute Details
#input_qty ⇒ Quantity
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 15 def input_qty @input_qty end |
#inventory_available_date ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 23 def inventory_available_date @inventory_available_date end |
#ship_node ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 19 def ship_node @ship_node end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. input_qty = Quantity.from_hash(hash['inputQty']) if hash['inputQty'] ship_node = hash.key?('shipNode') ? hash['shipNode'] : nil inventory_available_date = hash.key?('inventoryAvailableDate') ? hash['inventoryAvailableDate'] : nil # Create object from extracted values. Node1.new(input_qty, ship_node, inventory_available_date) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['input_qty'] = 'inputQty' @_hash['ship_node'] = 'shipNode' @_hash['inventory_available_date'] = 'inventoryAvailableDate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} input_qty: #{@input_qty.inspect}, ship_node: #{@ship_node.inspect},"\ " inventory_available_date: #{@inventory_available_date.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
68 69 70 71 72 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node1.rb', line 68 def to_s class_name = self.class.name.split('::').last "<#{class_name} input_qty: #{@input_qty}, ship_node: #{@ship_node},"\ " inventory_available_date: #{@inventory_available_date}>" end |