Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Node2

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb

Overview

Node2 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(ship_node = nil, status = nil, errors = nil) ⇒ Node2

Returns a new instance of Node2.



44
45
46
47
48
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 44

def initialize(ship_node = nil, status = nil, errors = nil)
  @ship_node = ship_node
  @status = status
  @errors = errors
end

Instance Attribute Details

#errorsArray[Error1]

TODO: Write general description for this method

Returns:



23
24
25
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 23

def errors
  @errors
end

#ship_nodeString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 15

def ship_node
  @ship_node
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 19

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  ship_node = hash.key?('shipNode') ? hash['shipNode'] : nil
  status = hash.key?('status') ? hash['status'] : nil
  # Parameter is an array, so we need to iterate through it
  errors = nil
  unless hash['errors'].nil?
    errors = []
    hash['errors'].each do |structure|
      errors << (Error1.from_hash(structure) if structure)
    end
  end

  errors = nil unless hash.key?('errors')

  # Create object from extracted values.
  Node2.new(ship_node,
            status,
            errors)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['ship_node'] = 'shipNode'
  @_hash['status'] = 'status'
  @_hash['errors'] = 'errors'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



81
82
83
84
85
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 81

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} ship_node: #{@ship_node.inspect}, status: #{@status.inspect}, errors:"\
  " #{@errors.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node2.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} ship_node: #{@ship_node}, status: #{@status}, errors: #{@errors}>"
end