Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Node3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Node3
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb
Overview
Node3 Model.
Instance Attribute Summary collapse
-
#avail_to_sell_qty ⇒ Quantity
TODO: Write general description for this method.
-
#input_qty ⇒ Quantity
TODO: Write general description for this method.
-
#reserved_qty ⇒ Quantity
TODO: Write general description for this method.
-
#ship_node ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(ship_node = nil, input_qty = nil, avail_to_sell_qty = nil, reserved_qty = nil) ⇒ Node3
constructor
A new instance of Node3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(ship_node = nil, input_qty = nil, avail_to_sell_qty = nil, reserved_qty = nil) ⇒ Node3
Returns a new instance of Node3.
49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 49 def initialize(ship_node = nil, input_qty = nil, avail_to_sell_qty = nil, reserved_qty = nil) @ship_node = ship_node @input_qty = input_qty @avail_to_sell_qty = avail_to_sell_qty @reserved_qty = reserved_qty end |
Instance Attribute Details
#avail_to_sell_qty ⇒ Quantity
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 23 def avail_to_sell_qty @avail_to_sell_qty end |
#input_qty ⇒ Quantity
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 19 def input_qty @input_qty end |
#reserved_qty ⇒ Quantity
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 27 def reserved_qty @reserved_qty end |
#ship_node ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 15 def ship_node @ship_node end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. ship_node = hash.key?('shipNode') ? hash['shipNode'] : nil input_qty = Quantity.from_hash(hash['inputQty']) if hash['inputQty'] avail_to_sell_qty = Quantity.from_hash(hash['availToSellQty']) if hash['availToSellQty'] reserved_qty = Quantity.from_hash(hash['reservedQty']) if hash['reservedQty'] # Create object from extracted values. Node3.new(ship_node, input_qty, avail_to_sell_qty, reserved_qty) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['ship_node'] = 'shipNode' @_hash['input_qty'] = 'inputQty' @_hash['avail_to_sell_qty'] = 'availToSellQty' @_hash['reserved_qty'] = 'reservedQty' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} ship_node: #{@ship_node.inspect}, input_qty: #{@input_qty.inspect},"\ " avail_to_sell_qty: #{@avail_to_sell_qty.inspect}, reserved_qty: #{@reserved_qty.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/node3.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} ship_node: #{@ship_node}, input_qty: #{@input_qty}, avail_to_sell_qty:"\ " #{@avail_to_sell_qty}, reserved_qty: #{@reserved_qty}>" end |