Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderCancellation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderCancellation
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb
Overview
OrderCancellation Model.
Instance Attribute Summary collapse
-
#order_lines ⇒ OrderLines4
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(order_lines = nil) ⇒ OrderCancellation
constructor
A new instance of OrderCancellation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(order_lines = nil) ⇒ OrderCancellation
Returns a new instance of OrderCancellation.
34 35 36 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb', line 34 def initialize(order_lines = nil) @order_lines = order_lines end |
Instance Attribute Details
#order_lines ⇒ OrderLines4
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb', line 15 def order_lines @order_lines end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
39 40 41 42 43 44 45 46 47 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb', line 39 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. order_lines = OrderLines4.from_hash(hash['orderLines']) if hash['orderLines'] # Create object from extracted values. OrderCancellation.new(order_lines) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['order_lines'] = 'orderLines' @_hash end |
.nullables ⇒ Object
An array for nullable fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb', line 30 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb', line 25 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
56 57 58 59 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb', line 56 def inspect class_name = self.class.name.split('::').last "<#{class_name} order_lines: #{@order_lines.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
50 51 52 53 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_cancellation.rb', line 50 def to_s class_name = self.class.name.split('::').last "<#{class_name} order_lines: #{@order_lines}>" end |