Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderLine1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderLine1
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb
Overview
OrderLine1 Model.
Instance Attribute Summary collapse
-
#charges ⇒ Charges
TODO: Write general description for this method.
-
#config_id ⇒ String
TODO: Write general description for this method.
-
#fulfillment ⇒ Fulfillment
TODO: Write general description for this method.
-
#intent_to_cancel ⇒ String
TODO: Write general description for this method.
-
#item ⇒ Item3
TODO: Write general description for this method.
-
#line_number ⇒ String
TODO: Write general description for this method.
-
#order_line_quantity ⇒ StatusQuantity
TODO: Write general description for this method.
-
#order_line_statuses ⇒ OrderLineStatuses1
TODO: Write general description for this method.
-
#original_carrier_method ⇒ String
TODO: Write general description for this method.
-
#reference_line_id ⇒ String
TODO: Write general description for this method.
-
#refund ⇒ Refund
TODO: Write general description for this method.
-
#return_order_id ⇒ String
TODO: Write general description for this method.
-
#seller_order_id ⇒ String
TODO: Write general description for this method.
-
#serial_numbers ⇒ Array[String]
TODO: Write general description for this method.
-
#status_date ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(charges = nil, item = nil, line_number = nil, order_line_quantity = nil, order_line_statuses = nil, status_date = nil, return_order_id = nil, refund = nil, original_carrier_method = nil, reference_line_id = nil, fulfillment = nil, serial_numbers = nil, intent_to_cancel = nil, config_id = nil, seller_order_id = nil) ⇒ OrderLine1
constructor
A new instance of OrderLine1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(charges = nil, item = nil, line_number = nil, order_line_quantity = nil, order_line_statuses = nil, status_date = nil, return_order_id = nil, refund = nil, original_carrier_method = nil, reference_line_id = nil, fulfillment = nil, serial_numbers = nil, intent_to_cancel = nil, config_id = nil, seller_order_id = nil) ⇒ OrderLine1
Returns a new instance of OrderLine1.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 104 def initialize(charges = nil, item = nil, line_number = nil, order_line_quantity = nil, order_line_statuses = nil, status_date = nil, return_order_id = nil, refund = nil, original_carrier_method = nil, reference_line_id = nil, fulfillment = nil, serial_numbers = nil, intent_to_cancel = nil, config_id = nil, seller_order_id = nil) @charges = charges @item = item @line_number = line_number @order_line_quantity = order_line_quantity @order_line_statuses = order_line_statuses @status_date = status_date @return_order_id = return_order_id @refund = refund @original_carrier_method = original_carrier_method @reference_line_id = reference_line_id @fulfillment = fulfillment @serial_numbers = serial_numbers @intent_to_cancel = intent_to_cancel @config_id = config_id @seller_order_id = seller_order_id end |
Instance Attribute Details
#charges ⇒ Charges
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 15 def charges @charges end |
#config_id ⇒ String
TODO: Write general description for this method
67 68 69 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 67 def config_id @config_id end |
#fulfillment ⇒ Fulfillment
TODO: Write general description for this method
55 56 57 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 55 def fulfillment @fulfillment end |
#intent_to_cancel ⇒ String
TODO: Write general description for this method
63 64 65 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 63 def intent_to_cancel @intent_to_cancel end |
#item ⇒ Item3
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 19 def item @item end |
#line_number ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 23 def line_number @line_number end |
#order_line_quantity ⇒ StatusQuantity
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 27 def order_line_quantity @order_line_quantity end |
#order_line_statuses ⇒ OrderLineStatuses1
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 31 def order_line_statuses @order_line_statuses end |
#original_carrier_method ⇒ String
TODO: Write general description for this method
47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 47 def original_carrier_method @original_carrier_method end |
#reference_line_id ⇒ String
TODO: Write general description for this method
51 52 53 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 51 def reference_line_id @reference_line_id end |
#refund ⇒ Refund
TODO: Write general description for this method
43 44 45 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 43 def refund @refund end |
#return_order_id ⇒ String
TODO: Write general description for this method
39 40 41 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 39 def return_order_id @return_order_id end |
#seller_order_id ⇒ String
TODO: Write general description for this method
71 72 73 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 71 def seller_order_id @seller_order_id end |
#serial_numbers ⇒ Array[String]
TODO: Write general description for this method
59 60 61 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 59 def serial_numbers @serial_numbers end |
#status_date ⇒ String
TODO: Write general description for this method
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 35 def status_date @status_date end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 129 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. charges = Charges.from_hash(hash['charges']) if hash['charges'] item = Item3.from_hash(hash['item']) if hash['item'] line_number = hash.key?('lineNumber') ? hash['lineNumber'] : nil order_line_quantity = StatusQuantity.from_hash(hash['orderLineQuantity']) if hash['orderLineQuantity'] order_line_statuses = OrderLineStatuses1.from_hash(hash['orderLineStatuses']) if hash['orderLineStatuses'] status_date = hash.key?('statusDate') ? hash['statusDate'] : nil return_order_id = hash.key?('returnOrderId') ? hash['returnOrderId'] : nil refund = Refund.from_hash(hash['refund']) if hash['refund'] original_carrier_method = hash.key?('originalCarrierMethod') ? hash['originalCarrierMethod'] : nil reference_line_id = hash.key?('referenceLineId') ? hash['referenceLineId'] : nil fulfillment = Fulfillment.from_hash(hash['fulfillment']) if hash['fulfillment'] serial_numbers = hash.key?('serialNumbers') ? hash['serialNumbers'] : nil intent_to_cancel = hash.key?('intentToCancel') ? hash['intentToCancel'] : nil config_id = hash.key?('configId') ? hash['configId'] : nil seller_order_id = hash.key?('sellerOrderId') ? hash['sellerOrderId'] : nil # Create object from extracted values. OrderLine1.new(charges, item, line_number, order_line_quantity, order_line_statuses, status_date, return_order_id, refund, original_carrier_method, reference_line_id, fulfillment, serial_numbers, intent_to_cancel, config_id, seller_order_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 74 def self.names @_hash = {} if @_hash.nil? @_hash['charges'] = 'charges' @_hash['item'] = 'item' @_hash['line_number'] = 'lineNumber' @_hash['order_line_quantity'] = 'orderLineQuantity' @_hash['order_line_statuses'] = 'orderLineStatuses' @_hash['status_date'] = 'statusDate' @_hash['return_order_id'] = 'returnOrderId' @_hash['refund'] = 'refund' @_hash['original_carrier_method'] = 'originalCarrierMethod' @_hash['reference_line_id'] = 'referenceLineId' @_hash['fulfillment'] = 'fulfillment' @_hash['serial_numbers'] = 'serialNumbers' @_hash['intent_to_cancel'] = 'intentToCancel' @_hash['config_id'] = 'configId' @_hash['seller_order_id'] = 'sellerOrderId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
100 101 102 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 100 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
95 96 97 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 95 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
185 186 187 188 189 190 191 192 193 194 195 196 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 185 def inspect class_name = self.class.name.split('::').last "<#{class_name} charges: #{@charges.inspect}, item: #{@item.inspect}, line_number:"\ " #{@line_number.inspect}, order_line_quantity: #{@order_line_quantity.inspect},"\ " order_line_statuses: #{@order_line_statuses.inspect}, status_date:"\ " #{@status_date.inspect}, return_order_id: #{@return_order_id.inspect}, refund:"\ " #{@refund.inspect}, original_carrier_method: #{@original_carrier_method.inspect},"\ " reference_line_id: #{@reference_line_id.inspect}, fulfillment: #{@fulfillment.inspect},"\ " serial_numbers: #{@serial_numbers.inspect}, intent_to_cancel:"\ " #{@intent_to_cancel.inspect}, config_id: #{@config_id.inspect}, seller_order_id:"\ " #{@seller_order_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
173 174 175 176 177 178 179 180 181 182 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line1.rb', line 173 def to_s class_name = self.class.name.split('::').last "<#{class_name} charges: #{@charges}, item: #{@item}, line_number: #{@line_number},"\ " order_line_quantity: #{@order_line_quantity}, order_line_statuses:"\ " #{@order_line_statuses}, status_date: #{@status_date}, return_order_id:"\ " #{@return_order_id}, refund: #{@refund}, original_carrier_method:"\ " #{@original_carrier_method}, reference_line_id: #{@reference_line_id}, fulfillment:"\ " #{@fulfillment}, serial_numbers: #{@serial_numbers}, intent_to_cancel:"\ " #{@intent_to_cancel}, config_id: #{@config_id}, seller_order_id: #{@seller_order_id}>" end |