Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderLine2
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderLine2
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb
Overview
OrderLine2 Model.
Instance Attribute Summary collapse
-
#is_full_refund ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#line_number ⇒ String
TODO: Write general description for this method.
-
#refunds ⇒ Refunds
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(line_number = nil, refunds = nil, is_full_refund = nil) ⇒ OrderLine2
constructor
A new instance of OrderLine2.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(line_number = nil, refunds = nil, is_full_refund = nil) ⇒ OrderLine2
Returns a new instance of OrderLine2.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 44 def initialize(line_number = nil, refunds = nil, is_full_refund = nil) @line_number = line_number @refunds = refunds @is_full_refund = is_full_refund end |
Instance Attribute Details
#is_full_refund ⇒ TrueClass | FalseClass
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 23 def is_full_refund @is_full_refund end |
#line_number ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 15 def line_number @line_number end |
#refunds ⇒ Refunds
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 19 def refunds @refunds end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. line_number = hash.key?('lineNumber') ? hash['lineNumber'] : nil refunds = Refunds.from_hash(hash['refunds']) if hash['refunds'] is_full_refund = hash.key?('isFullRefund') ? hash['isFullRefund'] : nil # Create object from extracted values. OrderLine2.new(line_number, refunds, is_full_refund) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['line_number'] = 'lineNumber' @_hash['refunds'] = 'refunds' @_hash['is_full_refund'] = 'isFullRefund' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} line_number: #{@line_number.inspect}, refunds: #{@refunds.inspect},"\ " is_full_refund: #{@is_full_refund.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
66 67 68 69 70 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line2.rb', line 66 def to_s class_name = self.class.name.split('::').last "<#{class_name} line_number: #{@line_number}, refunds: #{@refunds}, is_full_refund:"\ " #{@is_full_refund}>" end |