Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderLineStatus3
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderLineStatus3
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb
Overview
OrderLineStatus3 Model.
Instance Attribute Summary collapse
-
#cancellation_reason ⇒ String
TODO: Write general description for this method.
-
#status ⇒ String
TODO: Write general description for this method.
-
#status_quantity ⇒ StatusQuantity
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(cancellation_reason = nil, status = nil, status_quantity = nil) ⇒ OrderLineStatus3
constructor
A new instance of OrderLineStatus3.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(cancellation_reason = nil, status = nil, status_quantity = nil) ⇒ OrderLineStatus3
Returns a new instance of OrderLineStatus3.
44 45 46 47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 44 def initialize(cancellation_reason = nil, status = nil, status_quantity = nil) @cancellation_reason = cancellation_reason @status = status @status_quantity = status_quantity end |
Instance Attribute Details
#cancellation_reason ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 15 def cancellation_reason @cancellation_reason end |
#status ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 19 def status @status end |
#status_quantity ⇒ StatusQuantity
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 23 def status_quantity @status_quantity end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. cancellation_reason = hash.key?('cancellationReason') ? hash['cancellationReason'] : nil status = hash.key?('status') ? hash['status'] : nil status_quantity = StatusQuantity.from_hash(hash['statusQuantity']) if hash['statusQuantity'] # Create object from extracted values. OrderLineStatus3.new(cancellation_reason, status, status_quantity) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['cancellation_reason'] = 'cancellationReason' @_hash['status'] = 'status' @_hash['status_quantity'] = 'statusQuantity' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} cancellation_reason: #{@cancellation_reason.inspect}, status:"\ " #{@status.inspect}, status_quantity: #{@status_quantity.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
68 69 70 71 72 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_line_status3.rb', line 68 def to_s class_name = self.class.name.split('::').last "<#{class_name} cancellation_reason: #{@cancellation_reason}, status: #{@status},"\ " status_quantity: #{@status_quantity}>" end |