Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderSubTotal
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderSubTotal
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb
Overview
OrderSubTotal Model.
Instance Attribute Summary collapse
-
#sub_total_type ⇒ String
TODO: Write general description for this method.
-
#total_amount ⇒ TotalAmount
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(sub_total_type = nil, total_amount = nil) ⇒ OrderSubTotal
constructor
A new instance of OrderSubTotal.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(sub_total_type = nil, total_amount = nil) ⇒ OrderSubTotal
Returns a new instance of OrderSubTotal.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 39 def initialize(sub_total_type = nil, total_amount = nil) @sub_total_type = sub_total_type @total_amount = total_amount end |
Instance Attribute Details
#sub_total_type ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 15 def sub_total_type @sub_total_type end |
#total_amount ⇒ TotalAmount
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 19 def total_amount @total_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. sub_total_type = hash.key?('subTotalType') ? hash['subTotalType'] : nil total_amount = TotalAmount.from_hash(hash['totalAmount']) if hash['totalAmount'] # Create object from extracted values. OrderSubTotal.new(sub_total_type, total_amount) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['sub_total_type'] = 'subTotalType' @_hash['total_amount'] = 'totalAmount' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 68 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} sub_total_type: #{@sub_total_type.inspect}, total_amount:"\ " #{@total_amount.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_sub_total.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} sub_total_type: #{@sub_total_type}, total_amount: #{@total_amount}>" end |