Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::PageContext
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::PageContext
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb
Overview
PageContext Model.
Instance Attribute Summary collapse
-
#current_page_count ⇒ Integer
TODO: Write general description for this method.
-
#page_no ⇒ Integer
TODO: Write general description for this method.
-
#total_count ⇒ Integer
TODO: Write general description for this method.
-
#total_pages ⇒ Integer
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(page_no = nil, current_page_count = nil, total_count = nil, total_pages = nil) ⇒ PageContext
constructor
A new instance of PageContext.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(page_no = nil, current_page_count = nil, total_count = nil, total_pages = nil) ⇒ PageContext
Returns a new instance of PageContext.
49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 49 def initialize(page_no = nil, current_page_count = nil, total_count = nil, total_pages = nil) @page_no = page_no @current_page_count = current_page_count @total_count = total_count @total_pages = total_pages end |
Instance Attribute Details
#current_page_count ⇒ Integer
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 19 def current_page_count @current_page_count end |
#page_no ⇒ Integer
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 15 def page_no @page_no end |
#total_count ⇒ Integer
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 23 def total_count @total_count end |
#total_pages ⇒ Integer
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 27 def total_pages @total_pages end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. page_no = hash.key?('pageNo') ? hash['pageNo'] : nil current_page_count = hash.key?('currentPageCount') ? hash['currentPageCount'] : nil total_count = hash.key?('totalCount') ? hash['totalCount'] : nil total_pages = hash.key?('totalPages') ? hash['totalPages'] : nil # Create object from extracted values. PageContext.new(page_no, current_page_count, total_count, total_pages) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['page_no'] = 'pageNo' @_hash['current_page_count'] = 'currentPageCount' @_hash['total_count'] = 'totalCount' @_hash['total_pages'] = 'totalPages' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 88 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} page_no: #{@page_no.inspect}, current_page_count:"\ " #{@current_page_count.inspect}, total_count: #{@total_count.inspect}, total_pages:"\ " #{@total_pages.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/page_context.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} page_no: #{@page_no}, current_page_count: #{@current_page_count},"\ " total_count: #{@total_count}, total_pages: #{@total_pages}>" end |