Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::PhoneValidity
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::PhoneValidity
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb
Overview
PhoneValidity Model.
Instance Attribute Summary collapse
-
#validated_by ⇒ String
TODO: Write general description for this method.
-
#validated_date ⇒ String
TODO: Write general description for this method.
-
#validation_status ⇒ String
TODO: Write general description for this method.
-
#validation_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(validation_type = nil, validation_status = nil, validated_date = nil, validated_by = nil) ⇒ PhoneValidity
constructor
A new instance of PhoneValidity.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(validation_type = nil, validation_status = nil, validated_date = nil, validated_by = nil) ⇒ PhoneValidity
Returns a new instance of PhoneValidity.
49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 49 def initialize(validation_type = nil, validation_status = nil, validated_date = nil, validated_by = nil) @validation_type = validation_type @validation_status = validation_status @validated_date = validated_date @validated_by = validated_by end |
Instance Attribute Details
#validated_by ⇒ String
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 27 def validated_by @validated_by end |
#validated_date ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 23 def validated_date @validated_date end |
#validation_status ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 19 def validation_status @validation_status end |
#validation_type ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 15 def validation_type @validation_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. validation_type = hash.key?('validationType') ? hash['validationType'] : nil validation_status = hash.key?('validationStatus') ? hash['validationStatus'] : nil validated_date = hash.key?('validatedDate') ? hash['validatedDate'] : nil validated_by = hash.key?('validatedBy') ? hash['validatedBy'] : nil # Create object from extracted values. PhoneValidity.new(validation_type, validation_status, validated_date, validated_by) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['validation_type'] = 'validationType' @_hash['validation_status'] = 'validationStatus' @_hash['validated_date'] = 'validatedDate' @_hash['validated_by'] = 'validatedBy' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
85 86 87 88 89 90 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 85 def inspect class_name = self.class.name.split('::').last "<#{class_name} validation_type: #{@validation_type.inspect}, validation_status:"\ " #{@validation_status.inspect}, validated_date: #{@validated_date.inspect}, validated_by:"\ " #{@validated_by.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
77 78 79 80 81 82 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/phone_validity.rb', line 77 def to_s class_name = self.class.name.split('::').last "<#{class_name} validation_type: #{@validation_type}, validation_status:"\ " #{@validation_status}, validated_date: #{@validated_date}, validated_by:"\ " #{@validated_by}>" end |