Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Pricing
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Pricing
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb
Overview
Pricing Model.
Instance Attribute Summary collapse
-
#current_price ⇒ CurrentPrice
TODO: Write general description for this method.
-
#current_price_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(current_price_type = nil, current_price = nil) ⇒ Pricing
constructor
A new instance of Pricing.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(current_price_type = nil, current_price = nil) ⇒ Pricing
Returns a new instance of Pricing.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 39 def initialize(current_price_type = nil, current_price = nil) @current_price_type = current_price_type @current_price = current_price end |
Instance Attribute Details
#current_price ⇒ CurrentPrice
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 19 def current_price @current_price end |
#current_price_type ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 15 def current_price_type @current_price_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. current_price_type = hash.key?('currentPriceType') ? hash['currentPriceType'] : nil current_price = CurrentPrice.from_hash(hash['currentPrice']) if hash['currentPrice'] # Create object from extracted values. Pricing.new(current_price_type, current_price) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['current_price_type'] = 'currentPriceType' @_hash['current_price'] = 'currentPrice' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} current_price_type: #{@current_price_type.inspect}, current_price:"\ " #{@current_price.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/pricing.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} current_price_type: #{@current_price_type}, current_price:"\ " #{@current_price}>" end |