Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ProductType
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ProductType
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb
Overview
ProductType Model.
Instance Attribute Summary collapse
-
#description ⇒ String
TODO: Write general description for this method.
-
#product_type_name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(product_type_name = nil, description = nil) ⇒ ProductType
constructor
A new instance of ProductType.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(product_type_name = nil, description = nil) ⇒ ProductType
Returns a new instance of ProductType.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 39 def initialize(product_type_name = nil, description = nil) @product_type_name = product_type_name @description = description end |
Instance Attribute Details
#description ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 19 def description @description end |
#product_type_name ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 15 def product_type_name @product_type_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. product_type_name = hash.key?('productTypeName') ? hash['productTypeName'] : nil description = hash.key?('description') ? hash['description'] : nil # Create object from extracted values. ProductType.new(product_type_name, description) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['product_type_name'] = 'productTypeName' @_hash['description'] = 'description' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 69 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} product_type_name: #{@product_type_name.inspect}, description:"\ " #{@description.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/product_type.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} product_type_name: #{@product_type_name}, description: #{@description}>" end |