Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ProgramAction1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ProgramAction1
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb
Overview
ProgramAction1 Model.
Instance Attribute Summary collapse
-
#item_identifiers ⇒ Item
TODO: Write general description for this method.
-
#programs ⇒ Programs1
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(item_identifiers = nil, programs = nil) ⇒ ProgramAction1
constructor
A new instance of ProgramAction1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(item_identifiers = nil, programs = nil) ⇒ ProgramAction1
Returns a new instance of ProgramAction1.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 39 def initialize(item_identifiers = nil, programs = nil) @item_identifiers = item_identifiers @programs = programs end |
Instance Attribute Details
#item_identifiers ⇒ Item
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 15 def item_identifiers @item_identifiers end |
#programs ⇒ Programs1
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 19 def programs @programs end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. item_identifiers = Item.from_hash(hash['ItemIdentifiers']) if hash['ItemIdentifiers'] programs = Programs1.from_hash(hash['Programs']) if hash['Programs'] # Create object from extracted values. ProgramAction1.new(item_identifiers, programs) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['item_identifiers'] = 'ItemIdentifiers' @_hash['programs'] = 'Programs' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 68 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} item_identifiers: #{@item_identifiers.inspect}, programs:"\ " #{@programs.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action1.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} item_identifiers: #{@item_identifiers}, programs: #{@programs}>" end |