Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ProgramActionFeedHeader
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ProgramActionFeedHeader
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb
Overview
ProgramActionFeedHeader Model.
Instance Attribute Summary collapse
-
#feed_date ⇒ String
TODO: Write general description for this method.
-
#feed_type ⇒ String
TODO: Write general description for this method.
-
#locale ⇒ String
TODO: Write general description for this method.
-
#process_mode ⇒ String
TODO: Write general description for this method.
-
#request_batch_id ⇒ String
TODO: Write general description for this method.
-
#request_id ⇒ String
TODO: Write general description for this method.
-
#selling_channel ⇒ String
TODO: Write general description for this method.
-
#subset ⇒ String
TODO: Write general description for this method.
-
#version ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(request_id = nil, request_batch_id = nil, process_mode = nil, subset = nil, selling_channel = nil, version = nil, locale = nil, feed_date = nil, feed_type = nil) ⇒ ProgramActionFeedHeader
constructor
A new instance of ProgramActionFeedHeader.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(request_id = nil, request_batch_id = nil, process_mode = nil, subset = nil, selling_channel = nil, version = nil, locale = nil, feed_date = nil, feed_type = nil) ⇒ ProgramActionFeedHeader
Returns a new instance of ProgramActionFeedHeader.
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 74 def initialize(request_id = nil, request_batch_id = nil, process_mode = nil, subset = nil, selling_channel = nil, version = nil, locale = nil, feed_date = nil, feed_type = nil) @request_id = request_id @request_batch_id = request_batch_id @process_mode = process_mode @subset = subset @selling_channel = selling_channel @version = version @locale = locale @feed_date = feed_date @feed_type = feed_type end |
Instance Attribute Details
#feed_date ⇒ String
TODO: Write general description for this method
43 44 45 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 43 def feed_date @feed_date end |
#feed_type ⇒ String
TODO: Write general description for this method
47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 47 def feed_type @feed_type end |
#locale ⇒ String
TODO: Write general description for this method
39 40 41 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 39 def locale @locale end |
#process_mode ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 23 def process_mode @process_mode end |
#request_batch_id ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 19 def request_batch_id @request_batch_id end |
#request_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 15 def request_id @request_id end |
#selling_channel ⇒ String
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 31 def selling_channel @selling_channel end |
#subset ⇒ String
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 27 def subset @subset end |
#version ⇒ String
TODO: Write general description for this method
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 35 def version @version end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 89 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. request_id = hash.key?('requestId') ? hash['requestId'] : nil request_batch_id = hash.key?('requestBatchId') ? hash['requestBatchId'] : nil process_mode = hash.key?('processMode') ? hash['processMode'] : nil subset = hash.key?('subset') ? hash['subset'] : nil selling_channel = hash.key?('sellingChannel') ? hash['sellingChannel'] : nil version = hash.key?('version') ? hash['version'] : nil locale = hash.key?('locale') ? hash['locale'] : nil feed_date = hash.key?('feedDate') ? hash['feedDate'] : nil feed_type = hash.key?('feedType') ? hash['feedType'] : nil # Create object from extracted values. ProgramActionFeedHeader.new(request_id, request_batch_id, process_mode, subset, selling_channel, version, locale, feed_date, feed_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 50 def self.names @_hash = {} if @_hash.nil? @_hash['request_id'] = 'requestId' @_hash['request_batch_id'] = 'requestBatchId' @_hash['process_mode'] = 'processMode' @_hash['subset'] = 'subset' @_hash['selling_channel'] = 'sellingChannel' @_hash['version'] = 'version' @_hash['locale'] = 'locale' @_hash['feed_date'] = 'feedDate' @_hash['feed_type'] = 'feedType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
70 71 72 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 70 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
65 66 67 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 65 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
127 128 129 130 131 132 133 134 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 127 def inspect class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id.inspect}, request_batch_id:"\ " #{@request_batch_id.inspect}, process_mode: #{@process_mode.inspect}, subset:"\ " #{@subset.inspect}, selling_channel: #{@selling_channel.inspect}, version:"\ " #{@version.inspect}, locale: #{@locale.inspect}, feed_date: #{@feed_date.inspect},"\ " feed_type: #{@feed_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
118 119 120 121 122 123 124 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/program_action_feed_header.rb', line 118 def to_s class_name = self.class.name.split('::').last "<#{class_name} request_id: #{@request_id}, request_batch_id: #{@request_batch_id},"\ " process_mode: #{@process_mode}, subset: #{@subset}, selling_channel: #{@selling_channel},"\ " version: #{@version}, locale: #{@locale}, feed_date: #{@feed_date}, feed_type:"\ " #{@feed_type}>" end |