Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Programs
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Programs
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb
Overview
Programs Model.
Instance Attribute Summary collapse
-
#walmart_funded_incentives_enrollment ⇒ WalmartFundedIncentivesEnrollment
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(walmart_funded_incentives_enrollment = nil) ⇒ Programs
constructor
A new instance of Programs.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(walmart_funded_incentives_enrollment = nil) ⇒ Programs
Returns a new instance of Programs.
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb', line 35 def initialize(walmart_funded_incentives_enrollment = nil) @walmart_funded_incentives_enrollment = walmart_funded_incentives_enrollment end |
Instance Attribute Details
#walmart_funded_incentives_enrollment ⇒ WalmartFundedIncentivesEnrollment
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb', line 15 def walmart_funded_incentives_enrollment @walmart_funded_incentives_enrollment end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb', line 40 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. if hash['WalmartFundedIncentivesEnrollment'] walmart_funded_incentives_enrollment = WalmartFundedIncentivesEnrollment.from_hash(hash['WalmartFundedIncentivesEnrollment']) end # Create object from extracted values. Programs.new(walmart_funded_incentives_enrollment) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 23 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['walmart_funded_incentives_enrollment'] = 'WalmartFundedIncentivesEnrollment' @_hash end |
.nullables ⇒ Object
An array for nullable fields
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb', line 31 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
26 27 28 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb', line 26 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
60 61 62 63 64 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb', line 60 def inspect class_name = self.class.name.split('::').last "<#{class_name} walmart_funded_incentives_enrollment:"\ " #{@walmart_funded_incentives_enrollment.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
53 54 55 56 57 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/programs.rb', line 53 def to_s class_name = self.class.name.split('::').last "<#{class_name} walmart_funded_incentives_enrollment:"\ " #{@walmart_funded_incentives_enrollment}>" end |