Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::PurchaseOrderIdController

Inherits:
BaseController
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/controllers/purchase_order_id_controller.rb

Overview

PurchaseOrderIdController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent

Constructor Details

This class inherits a constructor from InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::BaseController

Instance Method Details

#anorder(product_info, replacement_info, purchase_order_id, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) ⇒ SuccessfulOperation42

Retrieves an order detail for a specific purchaseOrderId the image URL and product weight in response, if available. Allowed values are true or false. Provides additional attributes - originalCustomerOrderID, orderType - related to Replacement order, in response, if available. Allowed values are true or false. purchaseOrderId access token retrieved in the Token API call to track the consumer request by channel. Use the Consumer Channel Type received during onboarding unique ID which identifies each API call and used to track and debug issues; use a random generated GUID for this ID Name

Parameters:

  • product_info (TrueClass | FalseClass)

    Required parameter: Provides

  • replacement_info (TrueClass | FalseClass)

    Required parameter:

  • purchase_order_id (String)

    Required parameter: (Required)

  • wm_sec_access_token (String)

    Required parameter: (Required) The

  • wm_consumer_channel_type (String)

    Required parameter: A unique ID

  • wm_qos_correlation_id (String)

    Required parameter: (Required) A

  • wm_svc_name (String)

    Required parameter: (Required) Walmart Service

  • accept (String)

    Required parameter: TODO: type description here

Returns:



32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/controllers/purchase_order_id_controller.rb', line 32

def anorder(product_info,
            replacement_info,
            purchase_order_id,
            wm_sec_access_token,
            wm_consumer_channel_type,
            wm_qos_correlation_id,
            wm_svc_name,
            accept)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/orders/{purchaseOrderId}',
                                 Server::DEFAULT)
               .query_param(new_parameter(product_info, key: 'productInfo'))
               .query_param(new_parameter(replacement_info, key: 'replacementInfo'))
               .template_param(new_parameter(purchase_order_id, key: 'purchaseOrderId')
                                .should_encode(true))
               .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN'))
               .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE'))
               .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID'))
               .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME'))
               .header_param(new_parameter(accept, key: 'Accept')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(SuccessfulOperation42.method(:from_hash)))
    .execute
end