Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Refund6
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Refund6
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb
Overview
Refund6 Model.
Instance Attribute Summary collapse
-
#refund_charges ⇒ RefundCharges6
TODO: Write general description for this method.
-
#refund_comments ⇒ String
TODO: Write general description for this method.
-
#refund_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(refund_charges = nil, refund_id = nil, refund_comments = nil) ⇒ Refund6
constructor
A new instance of Refund6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(refund_charges = nil, refund_id = nil, refund_comments = nil) ⇒ Refund6
Returns a new instance of Refund6.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 44 def initialize(refund_charges = nil, refund_id = nil, refund_comments = nil) @refund_charges = refund_charges @refund_id = refund_id @refund_comments = refund_comments end |
Instance Attribute Details
#refund_charges ⇒ RefundCharges6
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 15 def refund_charges @refund_charges end |
#refund_comments ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 23 def refund_comments @refund_comments end |
#refund_id ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 19 def refund_id @refund_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. refund_charges = RefundCharges6.from_hash(hash['refundCharges']) if hash['refundCharges'] refund_id = hash.key?('refundId') ? hash['refundId'] : nil refund_comments = hash.key?('refundComments') ? hash['refundComments'] : nil # Create object from extracted values. Refund6.new(refund_charges, refund_id, refund_comments) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['refund_charges'] = 'refundCharges' @_hash['refund_id'] = 'refundId' @_hash['refund_comments'] = 'refundComments' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} refund_charges: #{@refund_charges.inspect}, refund_id:"\ " #{@refund_id.inspect}, refund_comments: #{@refund_comments.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund6.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} refund_charges: #{@refund_charges}, refund_id: #{@refund_id},"\ " refund_comments: #{@refund_comments}>" end |