Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::RefundCharge6
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::RefundCharge6
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb
Overview
RefundCharge6 Model.
Instance Attribute Summary collapse
-
#charge ⇒ Charge12
TODO: Write general description for this method.
-
#refund_reason ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(charge = nil, refund_reason = nil) ⇒ RefundCharge6
constructor
A new instance of RefundCharge6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(charge = nil, refund_reason = nil) ⇒ RefundCharge6
Returns a new instance of RefundCharge6.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 39 def initialize(charge = nil, refund_reason = nil) @charge = charge @refund_reason = refund_reason end |
Instance Attribute Details
#charge ⇒ Charge12
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 15 def charge @charge end |
#refund_reason ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 19 def refund_reason @refund_reason end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. charge = Charge12.from_hash(hash['charge']) if hash['charge'] refund_reason = hash.key?('refundReason') ? hash['refundReason'] : nil # Create object from extracted values. RefundCharge6.new(charge, refund_reason) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['charge'] = 'charge' @_hash['refund_reason'] = 'refundReason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} charge: #{@charge.inspect}, refund_reason: #{@refund_reason.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charge6.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} charge: #{@charge}, refund_reason: #{@refund_reason}>" end |