Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::RefundCharges6
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::RefundCharges6
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb
Overview
RefundCharges6 Model.
Instance Attribute Summary collapse
-
#refund_charge ⇒ Array[RefundCharge6]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(refund_charge = nil) ⇒ RefundCharges6
constructor
A new instance of RefundCharges6.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(refund_charge = nil) ⇒ RefundCharges6
Returns a new instance of RefundCharges6.
34 35 36 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb', line 34 def initialize(refund_charge = nil) @refund_charge = refund_charge end |
Instance Attribute Details
#refund_charge ⇒ Array[RefundCharge6]
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb', line 15 def refund_charge @refund_charge end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb', line 39 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it refund_charge = nil unless hash['refundCharge'].nil? refund_charge = [] hash['refundCharge'].each do |structure| refund_charge << (RefundCharge6.from_hash(structure) if structure) end end refund_charge = nil unless hash.key?('refundCharge') # Create object from extracted values. RefundCharges6.new(refund_charge) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['refund_charge'] = 'refundCharge' @_hash end |
.nullables ⇒ Object
An array for nullable fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb', line 30 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb', line 25 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} refund_charge: #{@refund_charge.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refund_charges6.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} refund_charge: #{@refund_charge}>" end |