Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Refunds

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb

Overview

Refunds Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(refund = nil) ⇒ Refunds

Returns a new instance of Refunds.



34
35
36
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb', line 34

def initialize(refund = nil)
  @refund = refund
end

Instance Attribute Details

#refundArray[Refund1]

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb', line 15

def refund
  @refund
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb', line 39

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  # Parameter is an array, so we need to iterate through it
  refund = nil
  unless hash['refund'].nil?
    refund = []
    hash['refund'].each do |structure|
      refund << (Refund1.from_hash(structure) if structure)
    end
  end

  refund = nil unless hash.key?('refund')

  # Create object from extracted values.
  Refunds.new(refund)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['refund'] = 'refund'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



65
66
67
68
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb', line 65

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} refund: #{@refund.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



59
60
61
62
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/refunds.rb', line 59

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} refund: #{@refund}>"
end