Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ReturnCenterAddress
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ReturnCenterAddress
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb
Overview
ReturnCenterAddress Model.
Instance Attribute Summary collapse
-
#address1 ⇒ String
TODO: Write general description for this method.
-
#address2 ⇒ String
TODO: Write general description for this method.
-
#city ⇒ String
TODO: Write general description for this method.
-
#country ⇒ String
TODO: Write general description for this method.
-
#day_phone ⇒ String
TODO: Write general description for this method.
-
#email_id ⇒ String
TODO: Write general description for this method.
-
#name ⇒ String
TODO: Write general description for this method.
-
#postal_code ⇒ String
TODO: Write general description for this method.
-
#state ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(address1 = nil, city = nil, country = nil, postal_code = nil, state = nil, name = nil, address2 = nil, day_phone = nil, email_id = nil) ⇒ ReturnCenterAddress
constructor
A new instance of ReturnCenterAddress.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(address1 = nil, city = nil, country = nil, postal_code = nil, state = nil, name = nil, address2 = nil, day_phone = nil, email_id = nil) ⇒ ReturnCenterAddress
Returns a new instance of ReturnCenterAddress.
74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 74 def initialize(address1 = nil, city = nil, country = nil, postal_code = nil, state = nil, name = nil, address2 = nil, day_phone = nil, email_id = nil) @address1 = address1 @city = city @country = country @postal_code = postal_code @state = state @name = name @address2 = address2 @day_phone = day_phone @email_id = email_id end |
Instance Attribute Details
#address1 ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 15 def address1 @address1 end |
#address2 ⇒ String
TODO: Write general description for this method
39 40 41 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 39 def address2 @address2 end |
#city ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 19 def city @city end |
#country ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 23 def country @country end |
#day_phone ⇒ String
TODO: Write general description for this method
43 44 45 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 43 def day_phone @day_phone end |
#email_id ⇒ String
TODO: Write general description for this method
47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 47 def email_id @email_id end |
#name ⇒ String
TODO: Write general description for this method
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 35 def name @name end |
#postal_code ⇒ String
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 27 def postal_code @postal_code end |
#state ⇒ String
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 31 def state @state end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 89 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. address1 = hash.key?('address1') ? hash['address1'] : nil city = hash.key?('city') ? hash['city'] : nil country = hash.key?('country') ? hash['country'] : nil postal_code = hash.key?('postalCode') ? hash['postalCode'] : nil state = hash.key?('state') ? hash['state'] : nil name = hash.key?('name') ? hash['name'] : nil address2 = hash.key?('address2') ? hash['address2'] : nil day_phone = hash.key?('dayPhone') ? hash['dayPhone'] : nil email_id = hash.key?('emailId') ? hash['emailId'] : nil # Create object from extracted values. ReturnCenterAddress.new(address1, city, country, postal_code, state, name, address2, day_phone, email_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 50 def self.names @_hash = {} if @_hash.nil? @_hash['address1'] = 'address1' @_hash['city'] = 'city' @_hash['country'] = 'country' @_hash['postal_code'] = 'postalCode' @_hash['state'] = 'state' @_hash['name'] = 'name' @_hash['address2'] = 'address2' @_hash['day_phone'] = 'dayPhone' @_hash['email_id'] = 'emailId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
70 71 72 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 70 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
65 66 67 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 65 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
124 125 126 127 128 129 130 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 124 def inspect class_name = self.class.name.split('::').last "<#{class_name} address1: #{@address1.inspect}, city: #{@city.inspect}, country:"\ " #{@country.inspect}, postal_code: #{@postal_code.inspect}, state: #{@state.inspect}, name:"\ " #{@name.inspect}, address2: #{@address2.inspect}, day_phone: #{@day_phone.inspect},"\ " email_id: #{@email_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
116 117 118 119 120 121 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/return_center_address.rb', line 116 def to_s class_name = self.class.name.split('::').last "<#{class_name} address1: #{@address1}, city: #{@city}, country: #{@country}, postal_code:"\ " #{@postal_code}, state: #{@state}, name: #{@name}, address2: #{@address2}, day_phone:"\ " #{@day_phone}, email_id: #{@email_id}>" end |