Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ShipNode
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::ShipNode
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb
Overview
ShipNode Model.
Instance Attribute Summary collapse
-
#avail_to_sell_qty ⇒ String
TODO: Write general description for this method.
-
#modified_date ⇒ String
TODO: Write general description for this method.
-
#on_hand_qty ⇒ String
TODO: Write general description for this method.
-
#ship_node_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(modified_date = nil, avail_to_sell_qty = nil, on_hand_qty = nil, ship_node_type = nil) ⇒ ShipNode
constructor
A new instance of ShipNode.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(modified_date = nil, avail_to_sell_qty = nil, on_hand_qty = nil, ship_node_type = nil) ⇒ ShipNode
Returns a new instance of ShipNode.
49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 49 def initialize(modified_date = nil, avail_to_sell_qty = nil, on_hand_qty = nil, ship_node_type = nil) @modified_date = modified_date @avail_to_sell_qty = avail_to_sell_qty @on_hand_qty = on_hand_qty @ship_node_type = ship_node_type end |
Instance Attribute Details
#avail_to_sell_qty ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 19 def avail_to_sell_qty @avail_to_sell_qty end |
#modified_date ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 15 def modified_date @modified_date end |
#on_hand_qty ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 23 def on_hand_qty @on_hand_qty end |
#ship_node_type ⇒ String
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 27 def ship_node_type @ship_node_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 58 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. modified_date = hash.key?('modifiedDate') ? hash['modifiedDate'] : nil avail_to_sell_qty = hash.key?('availToSellQty') ? hash['availToSellQty'] : nil on_hand_qty = hash.key?('onHandQty') ? hash['onHandQty'] : nil ship_node_type = hash.key?('shipNodeType') ? hash['shipNodeType'] : nil # Create object from extracted values. ShipNode.new(modified_date, avail_to_sell_qty, on_hand_qty, ship_node_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
30 31 32 33 34 35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 30 def self.names @_hash = {} if @_hash.nil? @_hash['modified_date'] = 'modifiedDate' @_hash['avail_to_sell_qty'] = 'availToSellQty' @_hash['on_hand_qty'] = 'onHandQty' @_hash['ship_node_type'] = 'shipNodeType' @_hash end |
.nullables ⇒ Object
An array for nullable fields
45 46 47 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 45 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 40 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
83 84 85 86 87 88 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 83 def inspect class_name = self.class.name.split('::').last "<#{class_name} modified_date: #{@modified_date.inspect}, avail_to_sell_qty:"\ " #{@avail_to_sell_qty.inspect}, on_hand_qty: #{@on_hand_qty.inspect}, ship_node_type:"\ " #{@ship_node_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 80 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/ship_node.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} modified_date: #{@modified_date}, avail_to_sell_qty: #{@avail_to_sell_qty},"\ " on_hand_qty: #{@on_hand_qty}, ship_node_type: #{@ship_node_type}>" end |