Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Strategy
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Strategy
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb
Overview
Strategy Model.
Instance Attribute Summary collapse
-
#adjustment_type ⇒ String
TODO: Write general description for this method.
-
#adjustment_value ⇒ Float
TODO: Write general description for this method.
-
#strategy_type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(strategy_type = nil, adjustment_type = nil, adjustment_value = nil) ⇒ Strategy
constructor
A new instance of Strategy.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(strategy_type = nil, adjustment_type = nil, adjustment_value = nil) ⇒ Strategy
Returns a new instance of Strategy.
44 45 46 47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 44 def initialize(strategy_type = nil, adjustment_type = nil, adjustment_value = nil) @strategy_type = strategy_type @adjustment_type = adjustment_type @adjustment_value = adjustment_value end |
Instance Attribute Details
#adjustment_type ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 19 def adjustment_type @adjustment_type end |
#adjustment_value ⇒ Float
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 23 def adjustment_value @adjustment_value end |
#strategy_type ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 15 def strategy_type @strategy_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. strategy_type = hash.key?('strategyType') ? hash['strategyType'] : nil adjustment_type = hash.key?('adjustmentType') ? hash['adjustmentType'] : nil adjustment_value = hash.key?('adjustmentValue') ? hash['adjustmentValue'] : nil # Create object from extracted values. Strategy.new(strategy_type, adjustment_type, adjustment_value) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['strategy_type'] = 'strategyType' @_hash['adjustment_type'] = 'adjustmentType' @_hash['adjustment_value'] = 'adjustmentValue' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
76 77 78 79 80 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 76 def inspect class_name = self.class.name.split('::').last "<#{class_name} strategy_type: #{@strategy_type.inspect}, adjustment_type:"\ " #{@adjustment_type.inspect}, adjustment_value: #{@adjustment_value.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 73 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/strategy.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} strategy_type: #{@strategy_type}, adjustment_type: #{@adjustment_type},"\ " adjustment_value: #{@adjustment_value}>" end |