Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Subcategory
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Subcategory
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb
Overview
Subcategory Model.
Instance Attribute Summary collapse
-
#sub_category_id ⇒ String
TODO: Write general description for this method.
-
#sub_category_name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(sub_category_name = nil, sub_category_id = nil) ⇒ Subcategory
constructor
A new instance of Subcategory.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(sub_category_name = nil, sub_category_id = nil) ⇒ Subcategory
Returns a new instance of Subcategory.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 39 def initialize(sub_category_name = nil, sub_category_id = nil) @sub_category_name = sub_category_name @sub_category_id = sub_category_id end |
Instance Attribute Details
#sub_category_id ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 19 def sub_category_id @sub_category_id end |
#sub_category_name ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 15 def sub_category_name @sub_category_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. sub_category_name = hash.key?('subCategoryName') ? hash['subCategoryName'] : nil sub_category_id = hash.key?('subCategoryId') ? hash['subCategoryId'] : nil # Create object from extracted values. Subcategory.new(sub_category_name, sub_category_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['sub_category_name'] = 'subCategoryName' @_hash['sub_category_id'] = 'subCategoryId' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} sub_category_name: #{@sub_category_name.inspect}, sub_category_id:"\ " #{@sub_category_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/subcategory.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} sub_category_name: #{@sub_category_name}, sub_category_id:"\ " #{@sub_category_id}>" end |