Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb
Overview
SuccessfulOperation Model.
Instance Attribute Summary collapse
-
#inventory_available_date ⇒ String
TODO: Write general description for this method.
-
#quantity ⇒ Quantity
TODO: Write general description for this method.
-
#sku ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(quantity = nil, sku = nil, inventory_available_date = nil) ⇒ SuccessfulOperation
constructor
A new instance of SuccessfulOperation.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(quantity = nil, sku = nil, inventory_available_date = nil) ⇒ SuccessfulOperation
Returns a new instance of SuccessfulOperation.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 44 def initialize(quantity = nil, sku = nil, inventory_available_date = nil) @quantity = quantity @sku = sku @inventory_available_date = inventory_available_date end |
Instance Attribute Details
#inventory_available_date ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 23 def inventory_available_date @inventory_available_date end |
#quantity ⇒ Quantity
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 15 def quantity @quantity end |
#sku ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 19 def sku @sku end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. quantity = Quantity.from_hash(hash['quantity']) if hash['quantity'] sku = hash.key?('sku') ? hash['sku'] : nil inventory_available_date = hash.key?('inventoryAvailableDate') ? hash['inventoryAvailableDate'] : nil # Create object from extracted values. SuccessfulOperation.new(quantity, sku, inventory_available_date) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['quantity'] = 'quantity' @_hash['sku'] = 'sku' @_hash['inventory_available_date'] = 'inventoryAvailableDate' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} quantity: #{@quantity.inspect}, sku: #{@sku.inspect},"\ " inventory_available_date: #{@inventory_available_date.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} quantity: #{@quantity}, sku: #{@sku}, inventory_available_date:"\ " #{@inventory_available_date}>" end |