Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation1
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation1
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb
Overview
SuccessfulOperation1 Model.
Instance Attribute Summary collapse
-
#additional_properties ⇒ String
TODO: Write general description for this method.
-
#properties ⇒ Object
TODO: Write general description for this method.
-
#required ⇒ Array[String]
TODO: Write general description for this method.
-
#schema ⇒ String
TODO: Write general description for this method.
-
#title ⇒ String
TODO: Write general description for this method.
-
#type ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(schema = nil, additional_properties = nil, properties = nil, required = nil, title = nil, type = nil) ⇒ SuccessfulOperation1
constructor
A new instance of SuccessfulOperation1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(schema = nil, additional_properties = nil, properties = nil, required = nil, title = nil, type = nil) ⇒ SuccessfulOperation1
Returns a new instance of SuccessfulOperation1.
59 60 61 62 63 64 65 66 67 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 59 def initialize(schema = nil, additional_properties = nil, properties = nil, required = nil, title = nil, type = nil) @schema = schema @additional_properties = additional_properties @properties = properties @required = required @title = title @type = type end |
Instance Attribute Details
#additional_properties ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 19 def additional_properties @additional_properties end |
#properties ⇒ Object
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 23 def properties @properties end |
#required ⇒ Array[String]
TODO: Write general description for this method
27 28 29 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 27 def required @required end |
#schema ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 15 def schema @schema end |
#title ⇒ String
TODO: Write general description for this method
31 32 33 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 31 def title @title end |
#type ⇒ String
TODO: Write general description for this method
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 35 def type @type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 70 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. schema = hash.key?('$schema') ? hash['$schema'] : nil additional_properties = hash.key?('additionalProperties') ? hash['additionalProperties'] : nil properties = hash.key?('properties') ? hash['properties'] : nil required = hash.key?('required') ? hash['required'] : nil title = hash.key?('title') ? hash['title'] : nil type = hash.key?('type') ? hash['type'] : nil # Create object from extracted values. SuccessfulOperation1.new(schema, additional_properties, properties, required, title, type) end |
.names ⇒ Object
A mapping from model property names to API property names.
38 39 40 41 42 43 44 45 46 47 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 38 def self.names @_hash = {} if @_hash.nil? @_hash['schema'] = '$schema' @_hash['additional_properties'] = 'additionalProperties' @_hash['properties'] = 'properties' @_hash['required'] = 'required' @_hash['title'] = 'title' @_hash['type'] = 'type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
55 56 57 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 55 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
50 51 52 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 50 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
99 100 101 102 103 104 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 99 def inspect class_name = self.class.name.split('::').last "<#{class_name} schema: #{@schema.inspect}, additional_properties:"\ " #{@additional_properties.inspect}, properties: #{@properties.inspect}, required:"\ " #{@required.inspect}, title: #{@title.inspect}, type: #{@type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
92 93 94 95 96 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation1.rb', line 92 def to_s class_name = self.class.name.split('::').last "<#{class_name} schema: #{@schema}, additional_properties: #{@additional_properties},"\ " properties: #{@properties}, required: #{@required}, title: #{@title}, type: #{@type}>" end |