Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation12

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb

Overview

SuccessfulOperation12 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(repricer_strategy = nil, strategy_collection_id = nil, enabled = nil, enable_repricer_for_promotion = nil, restore_seller_price_without_target = nil, enable_buybox_meet_external = nil, compare_with3p_offer_only = nil, strategies = nil) ⇒ SuccessfulOperation12

Returns a new instance of SuccessfulOperation12.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 70

def initialize(repricer_strategy = nil, strategy_collection_id = nil,
               enabled = nil, enable_repricer_for_promotion = nil,
               restore_seller_price_without_target = nil,
               enable_buybox_meet_external = nil,
               compare_with3p_offer_only = nil, strategies = nil)
  @repricer_strategy = repricer_strategy
  @strategy_collection_id = strategy_collection_id
  @enabled = enabled
  @enable_repricer_for_promotion = enable_repricer_for_promotion
  @restore_seller_price_without_target = restore_seller_price_without_target
  @enable_buybox_meet_external = enable_buybox_meet_external
  @compare_with3p_offer_only = compare_with3p_offer_only
  @strategies = strategies
end

Instance Attribute Details

#compare_with3p_offer_onlyTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


39
40
41
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 39

def compare_with3p_offer_only
  @compare_with3p_offer_only
end

#enable_buybox_meet_externalTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


35
36
37
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 35

def enable_buybox_meet_external
  @enable_buybox_meet_external
end

#enable_repricer_for_promotionTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


27
28
29
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 27

def enable_repricer_for_promotion
  @enable_repricer_for_promotion
end

#enabledTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


23
24
25
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 23

def enabled
  @enabled
end

#repricer_strategyString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 15

def repricer_strategy
  @repricer_strategy
end

#restore_seller_price_without_targetTrueClass | FalseClass

TODO: Write general description for this method

Returns:

  • (TrueClass | FalseClass)


31
32
33
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 31

def restore_seller_price_without_target
  @restore_seller_price_without_target
end

#strategiesArray[Strategy]

TODO: Write general description for this method

Returns:



43
44
45
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 43

def strategies
  @strategies
end

#strategy_collection_idString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 19

def strategy_collection_id
  @strategy_collection_id
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 86

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  repricer_strategy =
    hash.key?('repricerStrategy') ? hash['repricerStrategy'] : nil
  strategy_collection_id =
    hash.key?('strategyCollectionId') ? hash['strategyCollectionId'] : nil
  enabled = hash.key?('enabled') ? hash['enabled'] : nil
  enable_repricer_for_promotion =
    hash.key?('enableRepricerForPromotion') ? hash['enableRepricerForPromotion'] : nil
  restore_seller_price_without_target =
    hash.key?('restoreSellerPriceWithoutTarget') ? hash['restoreSellerPriceWithoutTarget'] : nil
  enable_buybox_meet_external =
    hash.key?('enableBuyboxMeetExternal') ? hash['enableBuyboxMeetExternal'] : nil
  compare_with3p_offer_only =
    hash.key?('compareWith3pOfferOnly') ? hash['compareWith3pOfferOnly'] : nil
  # Parameter is an array, so we need to iterate through it
  strategies = nil
  unless hash['strategies'].nil?
    strategies = []
    hash['strategies'].each do |structure|
      strategies << (Strategy.from_hash(structure) if structure)
    end
  end

  strategies = nil unless hash.key?('strategies')

  # Create object from extracted values.
  SuccessfulOperation12.new(repricer_strategy,
                            strategy_collection_id,
                            enabled,
                            enable_repricer_for_promotion,
                            restore_seller_price_without_target,
                            enable_buybox_meet_external,
                            compare_with3p_offer_only,
                            strategies)
end

.namesObject

A mapping from model property names to API property names.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 46

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['repricer_strategy'] = 'repricerStrategy'
  @_hash['strategy_collection_id'] = 'strategyCollectionId'
  @_hash['enabled'] = 'enabled'
  @_hash['enable_repricer_for_promotion'] = 'enableRepricerForPromotion'
  @_hash['restore_seller_price_without_target'] =
    'restoreSellerPriceWithoutTarget'
  @_hash['enable_buybox_meet_external'] = 'enableBuyboxMeetExternal'
  @_hash['compare_with3p_offer_only'] = 'compareWith3pOfferOnly'
  @_hash['strategies'] = 'strategies'
  @_hash
end

.nullablesObject

An array for nullable fields



66
67
68
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 66

def self.nullables
  []
end

.optionalsObject

An array for optional fields



61
62
63
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 61

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



137
138
139
140
141
142
143
144
145
146
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 137

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} repricer_strategy: #{@repricer_strategy.inspect}, strategy_collection_id:"\
  " #{@strategy_collection_id.inspect}, enabled: #{@enabled.inspect},"\
  " enable_repricer_for_promotion: #{@enable_repricer_for_promotion.inspect},"\
  " restore_seller_price_without_target: #{@restore_seller_price_without_target.inspect},"\
  " enable_buybox_meet_external: #{@enable_buybox_meet_external.inspect},"\
  " compare_with3p_offer_only: #{@compare_with3p_offer_only.inspect}, strategies:"\
  " #{@strategies.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



126
127
128
129
130
131
132
133
134
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation12.rb', line 126

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} repricer_strategy: #{@repricer_strategy}, strategy_collection_id:"\
  " #{@strategy_collection_id}, enabled: #{@enabled}, enable_repricer_for_promotion:"\
  " #{@enable_repricer_for_promotion}, restore_seller_price_without_target:"\
  " #{@restore_seller_price_without_target}, enable_buybox_meet_external:"\
  " #{@enable_buybox_meet_external}, compare_with3p_offer_only: #{@compare_with3p_offer_only},"\
  " strategies: #{@strategies}>"
end