Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation121
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation121
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb
Overview
SuccessfulOperation121 Model.
Instance Attribute Summary collapse
-
#mart_id ⇒ String
TODO: Write general description for this method.
-
#status_info ⇒ SetupCAPSKUAllLegacyRequest
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mart_id = nil, status_info = nil) ⇒ SuccessfulOperation121
constructor
A new instance of SuccessfulOperation121.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mart_id = nil, status_info = nil) ⇒ SuccessfulOperation121
Returns a new instance of SuccessfulOperation121.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 39 def initialize(mart_id = nil, status_info = nil) @mart_id = mart_id @status_info = status_info end |
Instance Attribute Details
#mart_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 15 def mart_id @mart_id end |
#status_info ⇒ SetupCAPSKUAllLegacyRequest
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 19 def status_info @status_info end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mart_id = hash.key?('martId') ? hash['martId'] : nil status_info = SetupCAPSKUAllLegacyRequest.from_hash(hash['statusInfo']) if hash['statusInfo'] # Create object from extracted values. SuccessfulOperation121.new(mart_id, status_info) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['mart_id'] = 'martId' @_hash['status_info'] = 'statusInfo' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} mart_id: #{@mart_id.inspect}, status_info: #{@status_info.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation121.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} mart_id: #{@mart_id}, status_info: #{@status_info}>" end |