Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation32

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb

Overview

SuccessfulOperation32 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(total_elements = nil, strategy_collections = nil) ⇒ SuccessfulOperation32

Returns a new instance of SuccessfulOperation32.



39
40
41
42
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 39

def initialize(total_elements = nil, strategy_collections = nil)
  @total_elements = total_elements
  @strategy_collections = strategy_collections
end

Instance Attribute Details

#strategy_collectionsArray[StrategyCollection]

TODO: Write general description for this method

Returns:



19
20
21
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 19

def strategy_collections
  @strategy_collections
end

#total_elementsInteger

TODO: Write general description for this method

Returns:

  • (Integer)


15
16
17
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 15

def total_elements
  @total_elements
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  total_elements = hash.key?('totalElements') ? hash['totalElements'] : nil
  # Parameter is an array, so we need to iterate through it
  strategy_collections = nil
  unless hash['strategyCollections'].nil?
    strategy_collections = []
    hash['strategyCollections'].each do |structure|
      strategy_collections << (StrategyCollection.from_hash(structure) if structure)
    end
  end

  strategy_collections = nil unless hash.key?('strategyCollections')

  # Create object from extracted values.
  SuccessfulOperation32.new(total_elements,
                            strategy_collections)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['total_elements'] = 'totalElements'
  @_hash['strategy_collections'] = 'strategyCollections'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



74
75
76
77
78
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 74

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} total_elements: #{@total_elements.inspect}, strategy_collections:"\
  " #{@strategy_collections.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



67
68
69
70
71
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation32.rb', line 67

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} total_elements: #{@total_elements}, strategy_collections:"\
  " #{@strategy_collections}>"
end