Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation43
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation43
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb
Overview
SuccessfulOperation43 Model.
Instance Attribute Summary collapse
-
#auto_enroll_enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
-
#is_disabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(auto_enroll_enabled = nil, is_disabled = nil) ⇒ SuccessfulOperation43
constructor
A new instance of SuccessfulOperation43.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(auto_enroll_enabled = nil, is_disabled = nil) ⇒ SuccessfulOperation43
Returns a new instance of SuccessfulOperation43.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 39 def initialize(auto_enroll_enabled = nil, is_disabled = nil) @auto_enroll_enabled = auto_enroll_enabled @is_disabled = is_disabled end |
Instance Attribute Details
#auto_enroll_enabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 15 def auto_enroll_enabled @auto_enroll_enabled end |
#is_disabled ⇒ TrueClass | FalseClass
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 19 def is_disabled @is_disabled end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. auto_enroll_enabled = hash.key?('autoEnrollEnabled') ? hash['autoEnrollEnabled'] : nil is_disabled = hash.key?('isDisabled') ? hash['isDisabled'] : nil # Create object from extracted values. SuccessfulOperation43.new(auto_enroll_enabled, is_disabled) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['auto_enroll_enabled'] = 'autoEnrollEnabled' @_hash['is_disabled'] = 'isDisabled' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} auto_enroll_enabled: #{@auto_enroll_enabled.inspect}, is_disabled:"\ " #{@is_disabled.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 63 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation43.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} auto_enroll_enabled: #{@auto_enroll_enabled}, is_disabled:"\ " #{@is_disabled}>" end |