Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation5
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation5
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb
Overview
SuccessfulOperation5 Model.
Instance Attribute Summary collapse
-
#additional_attributes ⇒ Object
TODO: Write general description for this method.
-
#errors ⇒ Object
TODO: Write general description for this method.
-
#feed_id ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(feed_id = nil, additional_attributes = nil, errors = nil) ⇒ SuccessfulOperation5
constructor
A new instance of SuccessfulOperation5.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(feed_id = nil, additional_attributes = nil, errors = nil) ⇒ SuccessfulOperation5
Returns a new instance of SuccessfulOperation5.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 44 def initialize(feed_id = nil, additional_attributes = nil, errors = nil) @feed_id = feed_id @additional_attributes = additional_attributes @errors = errors end |
Instance Attribute Details
#additional_attributes ⇒ Object
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 19 def additional_attributes @additional_attributes end |
#errors ⇒ Object
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 23 def errors @errors end |
#feed_id ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 15 def feed_id @feed_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. feed_id = hash.key?('feedId') ? hash['feedId'] : nil additional_attributes = hash.key?('additionalAttributes') ? hash['additionalAttributes'] : nil errors = hash.key?('errors') ? hash['errors'] : nil # Create object from extracted values. SuccessfulOperation5.new(feed_id, additional_attributes, errors) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['feed_id'] = 'feedId' @_hash['additional_attributes'] = 'additionalAttributes' @_hash['errors'] = 'errors' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} feed_id: #{@feed_id.inspect}, additional_attributes:"\ " #{@additional_attributes.inspect}, errors: #{@errors.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation5.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} feed_id: #{@feed_id}, additional_attributes: #{@additional_attributes},"\ " errors: #{@errors}>" end |