Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation51

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb

Overview

SuccessfulOperation51 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(item_taxonomy = nil, status = nil, payload = nil) ⇒ SuccessfulOperation51

Returns a new instance of SuccessfulOperation51.



44
45
46
47
48
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 44

def initialize(item_taxonomy = nil, status = nil, payload = nil)
  @item_taxonomy = item_taxonomy
  @status = status
  @payload = payload
end

Instance Attribute Details

#item_taxonomyItemTaxonomy

TODO: Write general description for this method

Returns:



15
16
17
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 15

def item_taxonomy
  @item_taxonomy
end

#payloadArray[Payload11]

TODO: Write general description for this method

Returns:



23
24
25
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 23

def payload
  @payload
end

#statusString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 19

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 51

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  item_taxonomy = ItemTaxonomy.from_hash(hash['itemTaxonomy']) if hash['itemTaxonomy']
  status = hash.key?('status') ? hash['status'] : nil
  # Parameter is an array, so we need to iterate through it
  payload = nil
  unless hash['payload'].nil?
    payload = []
    hash['payload'].each do |structure|
      payload << (Payload11.from_hash(structure) if structure)
    end
  end

  payload = nil unless hash.key?('payload')

  # Create object from extracted values.
  SuccessfulOperation51.new(item_taxonomy,
                            status,
                            payload)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['item_taxonomy'] = 'itemTaxonomy'
  @_hash['status'] = 'status'
  @_hash['payload'] = 'payload'
  @_hash
end

.nullablesObject

An array for nullable fields



40
41
42
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 40

def self.nullables
  []
end

.optionalsObject

An array for optional fields



35
36
37
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 35

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



82
83
84
85
86
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 82

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} item_taxonomy: #{@item_taxonomy.inspect}, status: #{@status.inspect},"\
  " payload: #{@payload.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



75
76
77
78
79
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation51.rb', line 75

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} item_taxonomy: #{@item_taxonomy}, status: #{@status}, payload:"\
  " #{@payload}>"
end