Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Tax
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Tax
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb
Overview
Tax Model.
Instance Attribute Summary collapse
-
#tax_amount ⇒ Price1
TODO: Write general description for this method.
-
#tax_name ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(tax_amount = nil, tax_name = nil) ⇒ Tax
constructor
A new instance of Tax.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(tax_amount = nil, tax_name = nil) ⇒ Tax
Returns a new instance of Tax.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 39 def initialize(tax_amount = nil, tax_name = nil) @tax_amount = tax_amount @tax_name = tax_name end |
Instance Attribute Details
#tax_amount ⇒ Price1
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 15 def tax_amount @tax_amount end |
#tax_name ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 19 def tax_name @tax_name end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. tax_amount = Price1.from_hash(hash['taxAmount']) if hash['taxAmount'] tax_name = hash.key?('taxName') ? hash['taxName'] : nil # Create object from extracted values. Tax.new(tax_amount, tax_name) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['tax_amount'] = 'taxAmount' @_hash['tax_name'] = 'taxName' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} tax_amount: #{@tax_amount.inspect}, tax_name: #{@tax_name.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/tax.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} tax_amount: #{@tax_amount}, tax_name: #{@tax_name}>" end |