Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::TotalAmount
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::TotalAmount
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb
Overview
TotalAmount Model.
Instance Attribute Summary collapse
-
#currency_amount ⇒ String
TODO: Write general description for this method.
-
#currency_unit ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(currency_amount = nil, currency_unit = nil) ⇒ TotalAmount
constructor
A new instance of TotalAmount.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(currency_amount = nil, currency_unit = nil) ⇒ TotalAmount
Returns a new instance of TotalAmount.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 39 def initialize(currency_amount = nil, currency_unit = nil) @currency_amount = currency_amount @currency_unit = currency_unit end |
Instance Attribute Details
#currency_amount ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 15 def currency_amount @currency_amount end |
#currency_unit ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 19 def currency_unit @currency_unit end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. currency_amount = hash.key?('currencyAmount') ? hash['currencyAmount'] : nil currency_unit = hash.key?('currencyUnit') ? hash['currencyUnit'] : nil # Create object from extracted values. TotalAmount.new(currency_amount, currency_unit) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['currency_amount'] = 'currencyAmount' @_hash['currency_unit'] = 'currencyUnit' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 69 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} currency_amount: #{@currency_amount.inspect}, currency_unit:"\ " #{@currency_unit.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/total_amount.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} currency_amount: #{@currency_amount}, currency_unit: #{@currency_unit}>" end |