Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::UpdatepricingforasingleitemRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb

Overview

UpdatepricingforasingleitemRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(sku = nil, pricing = nil) ⇒ UpdatepricingforasingleitemRequest

Returns a new instance of UpdatepricingforasingleitemRequest.



39
40
41
42
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 39

def initialize(sku = nil, pricing = nil)
  @sku = sku
  @pricing = pricing
end

Instance Attribute Details

#pricingArray[Pricing]

TODO: Write general description for this method

Returns:



19
20
21
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 19

def pricing
  @pricing
end

#skuString

TODO: Write general description for this method

Returns:

  • (String)


15
16
17
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 15

def sku
  @sku
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 45

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  sku = hash.key?('sku') ? hash['sku'] : nil
  # Parameter is an array, so we need to iterate through it
  pricing = nil
  unless hash['pricing'].nil?
    pricing = []
    hash['pricing'].each do |structure|
      pricing << (Pricing.from_hash(structure) if structure)
    end
  end

  pricing = nil unless hash.key?('pricing')

  # Create object from extracted values.
  UpdatepricingforasingleitemRequest.new(sku,
                                         pricing)
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['sku'] = 'sku'
  @_hash['pricing'] = 'pricing'
  @_hash
end

.nullablesObject

An array for nullable fields



35
36
37
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 35

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 30

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



73
74
75
76
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 73

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} sku: #{@sku.inspect}, pricing: #{@pricing.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



67
68
69
70
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingforasingleitem_request.rb', line 67

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} sku: #{@sku}, pricing: #{@pricing}>"
end