Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::UpdatepricingformultipleitemsinbulkNewRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::UpdatepricingformultipleitemsinbulkNewRequest
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb
Overview
UpdatepricingformultipleitemsinbulkNewRequest Model.
Instance Attribute Summary collapse
-
#mp_item ⇒ Array[MPItem]
TODO: Write general description for this method.
-
#mp_item_feed_header ⇒ MPItemFeedHeader
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(mp_item_feed_header = nil, mp_item = nil) ⇒ UpdatepricingformultipleitemsinbulkNewRequest
constructor
A new instance of UpdatepricingformultipleitemsinbulkNewRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(mp_item_feed_header = nil, mp_item = nil) ⇒ UpdatepricingformultipleitemsinbulkNewRequest
Returns a new instance of UpdatepricingformultipleitemsinbulkNewRequest.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 39 def initialize(mp_item_feed_header = nil, mp_item = nil) @mp_item_feed_header = mp_item_feed_header @mp_item = mp_item end |
Instance Attribute Details
#mp_item ⇒ Array[MPItem]
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 19 def mp_item @mp_item end |
#mp_item_feed_header ⇒ MPItemFeedHeader
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 15 def mp_item_feed_header @mp_item_feed_header end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. mp_item_feed_header = MPItemFeedHeader.from_hash(hash['MPItemFeedHeader']) if hash['MPItemFeedHeader'] # Parameter is an array, so we need to iterate through it mp_item = nil unless hash['MPItem'].nil? mp_item = [] hash['MPItem'].each do |structure| mp_item << (MPItem.from_hash(structure) if structure) end end mp_item = nil unless hash.key?('MPItem') # Create object from extracted values. UpdatepricingformultipleitemsinbulkNewRequest.new(mp_item_feed_header, mp_item) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['mp_item_feed_header'] = 'MPItemFeedHeader' @_hash['mp_item'] = 'MPItem' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} mp_item_feed_header: #{@mp_item_feed_header.inspect}, mp_item:"\ " #{@mp_item.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
68 69 70 71 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/updatepricingformultipleitemsinbulk_new_request.rb', line 68 def to_s class_name = self.class.name.split('::').last "<#{class_name} mp_item_feed_header: #{@mp_item_feed_header}, mp_item: #{@mp_item}>" end |