Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::VariantGroupInfo
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::VariantGroupInfo
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb
Overview
VariantGroupInfo Model.
Instance Attribute Summary collapse
-
#grouping_attributes ⇒ GroupingAttributes
TODO: Write general description for this method.
-
#is_primary ⇒ String
TODO: Write general description for this method.
-
#primary ⇒ String
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(is_primary = nil, grouping_attributes = nil, primary = nil) ⇒ VariantGroupInfo
constructor
A new instance of VariantGroupInfo.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(is_primary = nil, grouping_attributes = nil, primary = nil) ⇒ VariantGroupInfo
Returns a new instance of VariantGroupInfo.
44 45 46 47 48 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 44 def initialize(is_primary = nil, grouping_attributes = nil, primary = nil) @is_primary = is_primary @grouping_attributes = grouping_attributes @primary = primary end |
Instance Attribute Details
#grouping_attributes ⇒ GroupingAttributes
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 19 def grouping_attributes @grouping_attributes end |
#is_primary ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 15 def is_primary @is_primary end |
#primary ⇒ String
TODO: Write general description for this method
23 24 25 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 23 def primary @primary end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. is_primary = hash.key?('isPrimary') ? hash['isPrimary'] : nil grouping_attributes = GroupingAttributes.from_hash(hash['groupingAttributes']) if hash['groupingAttributes'] primary = hash.key?('primary') ? hash['primary'] : nil # Create object from extracted values. VariantGroupInfo.new(is_primary, grouping_attributes, primary) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['is_primary'] = 'isPrimary' @_hash['grouping_attributes'] = 'groupingAttributes' @_hash['primary'] = 'primary' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} is_primary: #{@is_primary.inspect}, grouping_attributes:"\ " #{@grouping_attributes.inspect}, primary: #{@primary.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variant_group_info.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} is_primary: #{@is_primary}, grouping_attributes: #{@grouping_attributes},"\ " primary: #{@primary}>" end |