Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Variants
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Variants
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb
Overview
Variants Model.
Instance Attribute Summary collapse
-
#variant_data ⇒ Array[VariantDatum]
TODO: Write general description for this method.
-
#variant_meta ⇒ Array[VariantMetum]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(variant_meta = nil, variant_data = nil) ⇒ Variants
constructor
A new instance of Variants.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(variant_meta = nil, variant_data = nil) ⇒ Variants
Returns a new instance of Variants.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 39 def initialize( = nil, variant_data = nil) @variant_meta = @variant_data = variant_data end |
Instance Attribute Details
#variant_data ⇒ Array[VariantDatum]
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 19 def variant_data @variant_data end |
#variant_meta ⇒ Array[VariantMetum]
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 15 def @variant_meta end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. # Parameter is an array, so we need to iterate through it = nil unless hash['variantMeta'].nil? = [] hash['variantMeta'].each do |structure| << (VariantMetum.from_hash(structure) if structure) end end = nil unless hash.key?('variantMeta') # Parameter is an array, so we need to iterate through it variant_data = nil unless hash['variantData'].nil? variant_data = [] hash['variantData'].each do |structure| variant_data << (VariantDatum.from_hash(structure) if structure) end end variant_data = nil unless hash.key?('variantData') # Create object from extracted values. Variants.new(, variant_data) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['variant_meta'] = 'variantMeta' @_hash['variant_data'] = 'variantData' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} variant_meta: #{@variant_meta.inspect}, variant_data:"\ " #{@variant_data.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
76 77 78 79 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/variants.rb', line 76 def to_s class_name = self.class.name.split('::').last "<#{class_name} variant_meta: #{@variant_meta}, variant_data: #{@variant_data}>" end |