Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::InventoriesController
- Inherits:
-
BaseController
- Object
- BaseController
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::InventoriesController
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/controllers/inventories_controller.rb
Overview
InventoriesController
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#multiple_item_inventoryfor_all_ship_nodes(limit, next_cursor, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) ⇒ SuccessfulOperation4
This API will retrieve the inventory count for all of a seller’s items across all ship nodes by item to ship node mapping.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent
Constructor Details
This class inherits a constructor from InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::BaseController
Instance Method Details
#multiple_item_inventoryfor_all_ship_nodes(limit, next_cursor, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) ⇒ SuccessfulOperation4
This API will retrieve the inventory count for all of a seller’s items across all ship nodes by item to ship node mapping. Inventory can be zero or non-zero. Please note that NextCursor value changes and it needs to be passed on from the previous call to next call. Cannot be more than 50. initial API call to indicate pagination. Specify nextCursor value to retrieve the next 50 items. access token retrieved in the Token API call to track the consumer request by channel. Use the Consumer Channel Type received during onboarding unique ID which identifies each API call and used to track and debug issues; use a random generated GUID for this ID Name
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/controllers/inventories_controller.rb', line 31 def multiple_item_inventoryfor_all_ship_nodes(limit, next_cursor, wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/inventories', Server::DEFAULT) .query_param(new_parameter(limit, key: 'limit')) .query_param(new_parameter(next_cursor, key: 'nextCursor')) .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN')) .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE')) .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID')) .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME')) .header_param(new_parameter(accept, key: 'Accept'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(SuccessfulOperation4.method(:from_hash))) .execute end |