Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderSummary
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::OrderSummary
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb
Overview
OrderSummary Model.
Instance Attribute Summary collapse
-
#order_sub_totals ⇒ Array[OrderSubTotal]
TODO: Write general description for this method.
-
#total_amount ⇒ TotalAmount
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(total_amount = nil, order_sub_totals = nil) ⇒ OrderSummary
constructor
A new instance of OrderSummary.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(total_amount = nil, order_sub_totals = nil) ⇒ OrderSummary
Returns a new instance of OrderSummary.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 39 def initialize(total_amount = nil, order_sub_totals = nil) @total_amount = total_amount @order_sub_totals = order_sub_totals end |
Instance Attribute Details
#order_sub_totals ⇒ Array[OrderSubTotal]
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 19 def order_sub_totals @order_sub_totals end |
#total_amount ⇒ TotalAmount
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 15 def total_amount @total_amount end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. total_amount = TotalAmount.from_hash(hash['totalAmount']) if hash['totalAmount'] # Parameter is an array, so we need to iterate through it order_sub_totals = nil unless hash['orderSubTotals'].nil? order_sub_totals = [] hash['orderSubTotals'].each do |structure| order_sub_totals << (OrderSubTotal.from_hash(structure) if structure) end end order_sub_totals = nil unless hash.key?('orderSubTotals') # Create object from extracted values. OrderSummary.new(total_amount, order_sub_totals) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['total_amount'] = 'totalAmount' @_hash['order_sub_totals'] = 'orderSubTotals' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 77 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} total_amount: #{@total_amount.inspect}, order_sub_totals:"\ " #{@order_sub_totals.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/order_summary.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} total_amount: #{@total_amount}, order_sub_totals: #{@order_sub_totals}>" end |