Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Payload11
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::Payload11
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb
Overview
Payload11 Model.
Instance Attribute Summary collapse
-
#category ⇒ String
TODO: Write general description for this method.
-
#subcategory ⇒ Array[Subcategory]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(category = nil, subcategory = nil) ⇒ Payload11
constructor
A new instance of Payload11.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(category = nil, subcategory = nil) ⇒ Payload11
Returns a new instance of Payload11.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 39 def initialize(category = nil, subcategory = nil) @category = category @subcategory = subcategory end |
Instance Attribute Details
#category ⇒ String
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 15 def category @category end |
#subcategory ⇒ Array[Subcategory]
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 19 def subcategory @subcategory end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. category = hash.key?('category') ? hash['category'] : nil # Parameter is an array, so we need to iterate through it subcategory = nil unless hash['subcategory'].nil? subcategory = [] hash['subcategory'].each do |structure| subcategory << (Subcategory.from_hash(structure) if structure) end end subcategory = nil unless hash.key?('subcategory') # Create object from extracted values. Payload11.new(category, subcategory) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['category'] = 'category' @_hash['subcategory'] = 'subcategory' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
73 74 75 76 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 73 def inspect class_name = self.class.name.split('::').last "<#{class_name} category: #{@category.inspect}, subcategory: #{@subcategory.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/payload11.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} category: #{@category}, subcategory: #{@subcategory}>" end |