Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::StrategiesController
- Inherits:
-
BaseController
- Object
- BaseController
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::StrategiesController
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/controllers/strategies_controller.rb
Overview
StrategiesController
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#retrieverepricerstrategydetails(wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) ⇒ SuccessfulOperation32
Retrieves the details of a specific repricer strategy that was previously created for items in Walmart Marketplace.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent
Constructor Details
This class inherits a constructor from InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::BaseController
Instance Method Details
#retrieverepricerstrategydetails(wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) ⇒ SuccessfulOperation32
Retrieves the details of a specific repricer strategy that was previously created for items in Walmart Marketplace.
Use this API to view the list of strategies used and details about the
strategy including the strategy collection name, status, assigned items count, and strategy type. For more information and usage examples, refer to the <a href=“developer.walmart.com/us-marketplace/docs/get-repricer-strat egy”>Pricing API Guide</a>. obtained from the Token API. This is required for authenticating requests to Walmart Marketplace APIs. to track the consumer request by channel. Use the Consumer Channel Type received during onboarding. identifies each API call and is used to track and debug issues. Use a randomly generated GUID for this ID. Walmart service being called.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/controllers/strategies_controller.rb', line 31 def retrieverepricerstrategydetails(wm_sec_access_token, wm_consumer_channel_type, wm_qos_correlation_id, wm_svc_name, accept) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/repricer/strategies', Server::DEFAULT) .header_param(new_parameter(wm_sec_access_token, key: 'WM_SEC.ACCESS_TOKEN')) .header_param(new_parameter(wm_consumer_channel_type, key: 'WM_CONSUMER.CHANNEL.TYPE')) .header_param(new_parameter(wm_qos_correlation_id, key: 'WM_QOS.CORRELATION_ID')) .header_param(new_parameter(wm_svc_name, key: 'WM_SVC.NAME')) .header_param(new_parameter(accept, key: 'Accept'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(SuccessfulOperation32.method(:from_hash))) .execute end |