Class: InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation62
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- InventoryManagementAndItemManagementAndOrderManagementAndPriceManagement::SuccessfulOperation62
- Defined in:
- lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb
Overview
SuccessfulOperation62 Model.
Instance Attribute Summary collapse
-
#page_context ⇒ PageContext
TODO: Write general description for this method.
-
#pricing_insights_response_list ⇒ Array[PricingInsightsResponseList]
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(page_context = nil, pricing_insights_response_list = nil) ⇒ SuccessfulOperation62
constructor
A new instance of SuccessfulOperation62.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(page_context = nil, pricing_insights_response_list = nil) ⇒ SuccessfulOperation62
Returns a new instance of SuccessfulOperation62.
39 40 41 42 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 39 def initialize(page_context = nil, pricing_insights_response_list = nil) @page_context = page_context @pricing_insights_response_list = pricing_insights_response_list end |
Instance Attribute Details
#page_context ⇒ PageContext
TODO: Write general description for this method
15 16 17 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 15 def page_context @page_context end |
#pricing_insights_response_list ⇒ Array[PricingInsightsResponseList]
TODO: Write general description for this method
19 20 21 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 19 def pricing_insights_response_list @pricing_insights_response_list end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 45 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. page_context = PageContext.from_hash(hash['pageContext']) if hash['pageContext'] # Parameter is an array, so we need to iterate through it pricing_insights_response_list = nil unless hash['pricingInsightsResponseList'].nil? pricing_insights_response_list = [] hash['pricingInsightsResponseList'].each do |structure| pricing_insights_response_list << (PricingInsightsResponseList.from_hash(structure) if structure) end end pricing_insights_response_list = nil unless hash.key?('pricingInsightsResponseList') # Create object from extracted values. SuccessfulOperation62.new(page_context, pricing_insights_response_list) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['page_context'] = 'pageContext' @_hash['pricing_insights_response_list'] = 'pricingInsightsResponseList' @_hash end |
.nullables ⇒ Object
An array for nullable fields
35 36 37 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 35 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 30 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} page_context: #{@page_context.inspect}, pricing_insights_response_list:"\ " #{@pricing_insights_response_list.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/inventory_management_and_item_management_and_order_management_and_price_management/models/successful_operation62.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} page_context: #{@page_context}, pricing_insights_response_list:"\ " #{@pricing_insights_response_list}>" end |